/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalPhasor.h"
#include "HvSignalRPole.h"
#include "HvControlCast.h"
#include "HvControlDelay.h"
#include "HvSignalLine.h"
#include "HvTable.h"
#include "HvControlIf.h"
#include "HvSignalTabwrite.h"
#include "HvControlPack.h"
#include "HvControlRandom.h"
#include "HvControlVar.h"
#include "HvMath.h"
#include "HvSignalDel1.h"
#include "HvControlBinop.h"
#include "HvControlSystem.h"
#include "HvSignalVar.h"
#include "HvSignalTabread.h"
#include "HvControlTabhead.h"
#include "HvControlSlice.h"
#include "HvControlUnop.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_10JBhDWc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mi05ABuW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_n4BF6pxL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_P6vEfGhQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DW425XPq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w0xpIJtP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_0logVoCA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_F0r5GMAQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cjl9tWBP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6Hkq6sZ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_aiWMVMZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_jLI3YYRH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_5LDOR2ri_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LmDBva4o_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_VTTufTcz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_dkAMXtbv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wnVkXYpY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k5uzdX23_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ryot0aI5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8Bs80l57_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I8UUNqz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UCnFb2Id_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xBQCMwnL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_GougMyTr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fxoTl2YJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_GkmxeHu0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IZkHshLi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sVQ0VCIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TvrjxELk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vL3T3KKO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_i4NDtaTG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_27i6FdhF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Vt26Mh4Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oqtVp36k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rNp03cbH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kqUDIQdt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2vaFFgsO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BJIm95Ky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vnZR2RDK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GSZTlf6E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eD8bTLaC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QuM31m9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BsP1RD6n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dk5ra3aj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4iYFbmSv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_E4VmHeA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_j8he2tA3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_jP7uM3XJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PYyxWNyZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k2Rs6x7w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_feweOHvU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_siiVy1ry_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HX8LSDUE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lWVhP7oF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_8hcgXIs6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SGEW7P5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rkgLh275_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xnZQ0DMS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_37KoMZuC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KCCAKbVA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wbxjTEd3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7nR9z8Mc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6gfAG3UW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_flQRvxuy_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_hiXztmuM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_unX49ARY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_vQrnjZVM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_QsvmDaXc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Ov4weLRk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_DhEajXR4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B05Mm9rM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AP5Fzc8P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zz2TLNtg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DcRW0h9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rIYcNqc9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1hRGgDDW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b2jSOW6B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q8rPxsYk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_qUsWkknu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IJgtsQPi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_j4BGTUgG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KImUKwxq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_IAAcowjL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_rsLGKoQz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_qD1sV7Me_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m3G5pWcx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SaUklO7Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6iLlKoIa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Xfy7u8Ct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n5DSBEhj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GI8c33w7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lkd1eUjl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oh60u2TU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vbMlTHLs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IRV9bTmd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uTQVDvbs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qg1DNFKf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_LMSlRzgO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xFCf5AHG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_nlmFnosH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_h8z30s9A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2Pmy94e0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xHde3dBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_7vvJkzSJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dwpgbpJf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kNY7zYZd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jqi3Dg6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lRohbuIL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5uTujj8k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XS55EPHY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pG1N2APW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_baroojZs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RzajhNHz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xTbTvziQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L0Zcmsfy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_w4d2Fotm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_jDcDPxe9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ldE8n61I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dd5dy3oX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dFOcwt4j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kxod4KEj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UIX0HPEm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_PDOmzqdP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XMChOPhl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ni9LAMmo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vQS1jC73_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_mrbnE00s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9U3eIGig_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1DFqjhcg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DJmFJZif_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kj5iUSPy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UIurLTxh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_McZVFKsU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y0z20Uo2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pWc7dupO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_JNl44N1c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GLCYTS09_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_m3M4bFrI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_j7w3qwJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xgQgwo8p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_YVLoTg64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_5Y0oTXRm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PI3gKktT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Wr9OEUS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t7v5Qj8N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_NPXxjbUR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6HTyPduT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RSuaxvkG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TvIcJxyF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dkcLWAyC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DY7GRYah_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1Z8zp1GM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L8vuJXsA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_taIOFxs5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WDN0LzUP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_B79UZDtn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_JZQIXUjS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_n5KmItgG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_EPBZpCCD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_7QQ8Wb3a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_TckizUKh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gEiUtrsV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SnbaHZMy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RksrUQJe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qPMuZSMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wCNPU8QG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cNSHQEQk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O9B4Guaw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_vFhA4tyn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oxCAhVjZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_UTsibJnN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dqiG0j9F_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_O54WzMEl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_K7WBBQGI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x58BOiPW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QleszN3Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rnL4OEi6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RajJekQm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_py2ep6Dk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W7o7EUp7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zwjnzep5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xl7X1u47_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Als21axD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zCfWwuVx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_CLAuVHuF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_8UdKbgql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_mD253U7R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IUccEDc8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ey7KTSaV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CC5zyJ8N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5JU08Ra6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lNCSRxRk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GDsnoZ65_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DTAV57HN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hj2Q872v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_AFdfPvmw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Qlys6dku_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YgGVYxl0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_pMWNNzN5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_p15j7FMz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pwNxxn7m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wQb8froX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UQobvX5G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qc5wcUqt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sTsgaN9N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fCmcyYgU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_05mt9mV8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_swYOleg7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1wWxIvmP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cTHcv3Wf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_37thxS8c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nShWxKUE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qBkcp5k7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bqpBZwch_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SVioVDmI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kfjbsqKY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2ZqkcuqP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JNxh1nnY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tHF48jcm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nRFUM0Fb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fbORZrjg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_doj7YWZj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IdToH0BY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bCerdtSk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yKq3XOcW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AuoTENys_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mNHSH7be_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GbfVv4Yt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7Q8UwBNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_5H3yOKr7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_QLeijHiS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JqqmszrS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_uHByafK6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_GQglguVz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gM0TTDPr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OXx4XpCM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AOYySgeR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dRvw6hfr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_apht3gib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fH0M4FET_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_geCnZB9N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PLvwRt3y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VK6KxGIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3j1Hd02f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qloyxXUx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VDKmmky4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_iCsspYTK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MOV4BC1T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HBmLO3Jl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XafsBEiL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_VBlee2b5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vY7MyGaq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r9FuqQeq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LlGrDop6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9xlqUdYw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GTBNgwzw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yJ1M7mOR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eZ9glY6a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LJk7muXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ki142gGi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_HiFfzFR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_IDweWNCU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Cf0oF6Xw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_uErxmGS5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Ieltx2ym_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_aZFTCRSn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EIQXuMC3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZdDIlE1m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r7FXHQmj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CGjsKKYy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tAsheEp2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sb9IinVk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_XPD1MOMq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FhtSHxc4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_C4m1GjIC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Fg4KlTcY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3g8AJhfu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_TEbwXFeY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_PFwPTWKO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I06Q2YJq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZUrgM17N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1yIJYxlx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_4GYOB3DO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FfLMXHnI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xWnRLA4o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JuJFHtJ7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DXL3GX6R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ODgrrtJx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_utCcG7ep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YFyAucWf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9TyClUkP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_331nt2nF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JpJAEayl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_kNlymjFX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_q1TN7IBi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DhELYRGe_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_rZNiafct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_mHXkthO2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CCXQBmnY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UNhlUMVR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p1Y1gRe0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rTrzRH0h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VssTYBWc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ucGjqHaA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_qB2wTfG7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2PPPyVsc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ST937eep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5enhUL8X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_hEQwcLqc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_LxbCx7gJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_qBNCpf9u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AqGUiTsy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DUQ0zlGQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dDiM0QuJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cjGNZEmo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jxF4dIUk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XfIdmImr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5FOjbGz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2t6k5FLc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EbZTCnMf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6YGnhvH2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sKhL8BeD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eJIAX18M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XigE9B95_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Thxd8N4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Db9oMUx0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Tw4ombWu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_DtNsl6il_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_LGOOmd0w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_UsPKnZC4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_97CzejBb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BvlAStti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d4scSQLp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JeUfZKJ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PNmiphkR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ioC7krKp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_rPaFgR69_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a9CbhJDY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_TTybr8Wr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_p83Xy4uz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_EaC6kLKx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_bXeBs3gO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_Cga4SIPa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RsOD759Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wmx4KygR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GUv3N79p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_r4Qc2K46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7rxVyv3g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XwnpfvQK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NikOfn9h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I1nCJbys_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f5RunY46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ue5CI3Lc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hCgPSAie_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mUy3xSdd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_znghL8xy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_MRi48z2n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_zQPtTaw6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_lGSDM78E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zAaWqPbJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_99Set3gK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_LWU36yW2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vNxch7Ca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9LQzEIhf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_if8CCAc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KMqDkACk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vkXqRwdU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UWdjgfn8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_lwzJdzf0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_50VIQsh8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_KtSWASmJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DyEUVPv5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_egrzvyJ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_cgSrdfzh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_SWzBDsf1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2qj4e2hV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9HknvAaZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TbBC2Tfm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_yKeDZUqU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ea3v9yin_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_71BiitOh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H4Fik5x4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9UxEqea2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_w8LC64eF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IEHtG3lO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YEoTTorX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_at2UT3XP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZlL3pCLg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wsc6x9MM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ffkdcGZA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_9vXcNQ0j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Ojldjkgl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_6v4mazhT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_rdzKRYQ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BcwYblLN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3jN862jj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1M6iZNso_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mTiDQ9Zy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kMhBHJbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tD9vNmhC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_hLUIyRXl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ytmbZKEA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_pBaXc0Rv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OrJJ709E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_St1YrJMw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_b6Qs53Zo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_BMSIfyoq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9nzKfAOn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bf8rbLL3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rGnLFc9h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kXBeNJaj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HZIqoziN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lsM20LhX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SGPKZk7a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YWccN7wY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HWweDBnY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hl412BBl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kT2oVM6B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PTUFSLg2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_McgfNoUb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_W6DshnkC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_juuoRfZc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1t6nBS8s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YiUKr1sQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_9256Hmrq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HL13zx6T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Axux86y9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IQ3hro5l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gmBvFW3U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MjS6xFPF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t4CsbJhk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9hjrcvcZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7Y9YPvHi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Ul3WUYYM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IqItg1RO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eSUZ5hmB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0uwaXlif_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YPKKqxDH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LBF9KxnU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VaTvxvmx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lmvXltf9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VAiBqgci_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_RhHB1aeA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pwOsg8XW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_axOUjR0o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4MzUMetc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CRuICYx9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aRbdoElY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UqP158i1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mHVtWhxf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CQ2i70mZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JNu3GXiu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qFSyqBm1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_turQTxhP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_plgUpczG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zS3PNeXY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eQCAi8h7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ij266CW3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ebIsJQMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8omP5RGF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5c8Bnot1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yFKRsTvl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CO3z9KXD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sUNZH49O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MzH7lMij_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_tYH8rM5h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0Zu3sZM5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_f9JLNq7Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E2pSBl7m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r5qafdjl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_bceuj3rT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_oOYF9uoQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_QbLvp6u0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ujqKaFGh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_0cs3btJ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_YAQgNGE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cqmTRvF2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p1YnRRZw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rJUnZxZ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F0pWbbn1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dHNp6Wng_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_le3leKpg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Z1pFxwMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PBKp3SIF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_v1w4txAI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9l63ipka_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_NWU12N7l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_2BW7oHOw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_AO9Dt6Us_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rvOwYJK4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_czngRaxr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OQ8mj4oW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UG3BLNco_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vyQEPXj4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_m6R3xXpG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4HNTCpEx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dkFYJPQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_diCMINwF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5pNXV8N5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8YPbw2c0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_S1lV9Zpk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dKtSKX0E_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_ItG7zIEt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7IRwgm6b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8BAqJt3P_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_1gUeSwtK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oyNvYQZF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SLSaTluj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CoEZQiQL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RLY1jNaJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aDYRWDMO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2UHXqDBZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_x2At1KcC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_A6xMTjV8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BTOddFVn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_j9VIuGnh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_gbmsKtBK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_VenX1utd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sWCuA4RG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rPjjoaRE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BIQRgPHS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_eDca5gLV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_vpFP4fCE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fCj1R3v7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vbU9AHRz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MUvUI2Ye_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TPWR5CRw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xt2C0tHQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3Exyyi8d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RIRl9yNl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CVXZj6jJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Wt3lE4fI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_NhZ8Y9PY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ARSQaKva_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_8Y3Co807_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HuKX1YxG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xnICDC5J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_05OKFJ5s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G9MGSe7H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nZPOBpXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nvcfzKBr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rEFjhTad_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zleVGB4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lcbEHw2b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GWFr8rlL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_621r2hdR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A5fFbub0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BUSAoNYG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SKaFzKuv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O0BZ53Gb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Myc0yjJp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dTPgtWIO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_31ihSQ87_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hTl5rXRZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IR0AUejU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FUItVXxU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9PUWI8CJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9RnwR4Vs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dNTv7MMJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UHMzXVdS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_55W7DggL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yqZWGToG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_70xehuI3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B8buSh8n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qwB3PUXu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sYIyHrMu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gCds5fKn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3G7jQZh1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rXUui6Oe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CYFkNQu8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xMHIpEIk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MCyhmUA4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HSR7tYnJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Bgddvaq4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_26BKYTzE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7ETtRdf4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pLgUOjVx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Hyb5ao0H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cNsyaV7Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wqHgPcBs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_THPmGcqh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8a2K9Vk6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HTaslcGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_buCVE288_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4nIwuM3m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XmbBXM5U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_21FpADwZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OAUVfwv1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xITV5XxO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_U0anIvcf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LsT4IpXr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SBXfJlGf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JLJ7jWWy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4VdAMdF5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xaCYwnlR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oyHj9GYv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_T04VZtaW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4LoD4si4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Dj8R1kiv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JC74RZnc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LGIAuMdq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5pTHeLHg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7D72dwu4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_G6acpR5r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HE5X18RS_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_HI3mnHp0;
  SignalLine sLine_tmHAd2VJ;
  SignalLine sLine_Opn3dCSY;
  SignalTabhead sTabhead_uUJZmkUt;
  SignalTabread sTabread_wAUzuz1y;
  SignalTabread sTabread_Gap3YKaQ;
  SignalTabhead sTabhead_90GwjrS1;
  SignalTabread sTabread_VaSkBIkc;
  SignalTabread sTabread_6D6eVyGA;
  SignalTabwrite sTabwrite_r7MPYTzx;
  SignalRPole sRPole_xu7hceyA;
  SignalDel1 sDel1_Ta73M6F0;
  SignalTabread sTabread_AO9Dt6Us;
  SignalTabwrite sTabwrite_m0F9mjOq;
  SignalTabread sTabread_qD1sV7Me;
  SignalRPole sRPole_qcxPoxe9;
  SignalLine sLine_IoQu5Bvj;
  SignalLine sLine_cxHaKAdV;
  SignalTabread sTabread_iCsspYTK;
  SignalTabread sTabread_PFwPTWKO;
  SignalTabread sTabread_qBNCpf9u;
  SignalTabread sTabread_Cga4SIPa;
  SignalTabread sTabread_BMSIfyoq;
  SignalTabread sTabread_SWzBDsf1;
  SignalTabwrite sTabwrite_8lQcHMil;
  SignalTabwrite sTabwrite_AjIvwtaR;
  SignalTabwrite sTabwrite_hVWls8Ft;
  SignalTabwrite sTabwrite_PMmodRQQ;
  SignalTabwrite sTabwrite_PoZ1RtTs;
  SignalTabwrite sTabwrite_65YL1yEJ;
  SignalTabread sTabread_7vvJkzSJ;
  SignalRPole sRPole_EHtjvt45;
  SignalTabread sTabread_PDOmzqdP;
  SignalRPole sRPole_yDGxBN4w;
  SignalTabread sTabread_5Y0oTXRm;
  SignalRPole sRPole_3pAafqwQ;
  SignalTabwrite sTabwrite_4YgJJoul;
  SignalTabwrite sTabwrite_fTGzFUHW;
  SignalTabwrite sTabwrite_faKXG8tJ;
  SignalTabwrite sTabwrite_EBcVXs82;
  SignalLine sLine_20hnk4af;
  ControlVar cVar_10JBhDWc;
  ControlVar cVar_mi05ABuW;
  ControlPack cPack_n4BF6pxL;
  ControlBinop cBinop_DW425XPq;
  ControlVar cVar_w0xpIJtP;
  ControlPack cPack_0logVoCA;
  ControlVar cVar_F0r5GMAQ;
  ControlVar cVar_cjl9tWBP;
  ControlDelay cDelay_jLI3YYRH;
  ControlDelay cDelay_5LDOR2ri;
  ControlBinop cBinop_VTTufTcz;
  HvTable hTable_dkAMXtbv;
  ControlBinop cBinop_k5uzdX23;
  ControlVar cVar_fxoTl2YJ;
  ControlBinop cBinop_IZkHshLi;
  ControlBinop cBinop_TvrjxELk;
  SignalVarf sVarf_96BBl98G;
  SignalVarf sVarf_3DxtU3SJ;
  SignalVarf sVarf_Ju40mYCt;
  ControlVar cVar_27i6FdhF;
  ControlBinop cBinop_oqtVp36k;
  ControlBinop cBinop_kqUDIQdt;
  SignalVarf sVarf_JH7sdhMR;
  SignalVarf sVarf_lpiJNm31;
  SignalVarf sVarf_ZwcNDYLG;
  ControlBinop cBinop_2vaFFgsO;
  ControlBinop cBinop_BJIm95Ky;
  ControlBinop cBinop_eD8bTLaC;
  ControlBinop cBinop_QuM31m9v;
  ControlBinop cBinop_BsP1RD6n;
  ControlBinop cBinop_Dk5ra3aj;
  ControlBinop cBinop_4iYFbmSv;
  ControlBinop cBinop_feweOHvU;
  ControlBinop cBinop_siiVy1ry;
  SignalVarf sVarf_F1JJac0h;
  ControlVar cVar_HX8LSDUE;
  ControlBinop cBinop_SGEW7P5V;
  ControlBinop cBinop_rkgLh275;
  ControlBinop cBinop_37KoMZuC;
  ControlBinop cBinop_KCCAKbVA;
  ControlBinop cBinop_wbxjTEd3;
  ControlBinop cBinop_7nR9z8Mc;
  ControlBinop cBinop_6gfAG3UW;
  SignalVarf sVarf_eLGq56RT;
  ControlBinop cBinop_hiXztmuM;
  ControlRandom cRandom_vQrnjZVM;
  ControlSlice cSlice_QsvmDaXc;
  ControlDelay cDelay_DhEajXR4;
  ControlVar cVar_DcRW0h9x;
  ControlBinop cBinop_1hRGgDDW;
  ControlBinop cBinop_b2jSOW6B;
  ControlBinop cBinop_Q8rPxsYk;
  ControlTabhead cTabhead_qUsWkknu;
  ControlVar cVar_KImUKwxq;
  ControlDelay cDelay_IAAcowjL;
  ControlDelay cDelay_rsLGKoQz;
  ControlBinop cBinop_m3G5pWcx;
  ControlBinop cBinop_SaUklO7Y;
  ControlBinop cBinop_6iLlKoIa;
  ControlBinop cBinop_oh60u2TU;
  ControlBinop cBinop_IRV9bTmd;
  ControlBinop cBinop_uTQVDvbs;
  ControlTabhead cTabhead_LMSlRzgO;
  ControlVar cVar_h8z30s9A;
  ControlDelay cDelay_2Pmy94e0;
  ControlDelay cDelay_xHde3dBO;
  ControlBinop cBinop_dwpgbpJf;
  ControlBinop cBinop_kNY7zYZd;
  ControlBinop cBinop_jqi3Dg6S;
  ControlBinop cBinop_baroojZs;
  ControlBinop cBinop_xTbTvziQ;
  ControlBinop cBinop_L0Zcmsfy;
  ControlTabhead cTabhead_jDcDPxe9;
  ControlVar cVar_dFOcwt4j;
  ControlDelay cDelay_kxod4KEj;
  ControlDelay cDelay_UIX0HPEm;
  ControlBinop cBinop_XMChOPhl;
  ControlBinop cBinop_ni9LAMmo;
  ControlBinop cBinop_vQS1jC73;
  ControlBinop cBinop_Kj5iUSPy;
  ControlBinop cBinop_McZVFKsU;
  ControlBinop cBinop_y0z20Uo2;
  ControlTabhead cTabhead_JNl44N1c;
  ControlVar cVar_j7w3qwJV;
  ControlDelay cDelay_xgQgwo8p;
  ControlDelay cDelay_YVLoTg64;
  ControlBinop cBinop_PI3gKktT;
  ControlBinop cBinop_5Wr9OEUS;
  ControlBinop cBinop_t7v5Qj8N;
  ControlBinop cBinop_dkcLWAyC;
  ControlBinop cBinop_1Z8zp1GM;
  ControlBinop cBinop_L8vuJXsA;
  ControlDelay cDelay_JZQIXUjS;
  ControlDelay cDelay_n5KmItgG;
  ControlBinop cBinop_7QQ8Wb3a;
  HvTable hTable_TckizUKh;
  ControlBinop cBinop_SnbaHZMy;
  ControlDelay cDelay_oxCAhVjZ;
  ControlDelay cDelay_UTsibJnN;
  ControlBinop cBinop_O54WzMEl;
  HvTable hTable_K7WBBQGI;
  ControlBinop cBinop_QleszN3Z;
  ControlDelay cDelay_Als21axD;
  ControlDelay cDelay_zCfWwuVx;
  ControlBinop cBinop_8UdKbgql;
  HvTable hTable_mD253U7R;
  ControlBinop cBinop_ey7KTSaV;
  ControlDelay cDelay_AFdfPvmw;
  ControlDelay cDelay_Qlys6dku;
  ControlBinop cBinop_pMWNNzN5;
  HvTable hTable_p15j7FMz;
  ControlBinop cBinop_wQb8froX;
  ControlPack cPack_05mt9mV8;
  ControlPack cPack_swYOleg7;
  ControlBinop cBinop_1wWxIvmP;
  ControlBinop cBinop_cTHcv3Wf;
  ControlVar cVar_37thxS8c;
  ControlBinop cBinop_bqpBZwch;
  ControlBinop cBinop_SVioVDmI;
  SignalVarf sVarf_XNiR5GyA;
  ControlBinop cBinop_2ZqkcuqP;
  ControlBinop cBinop_JNxh1nnY;
  ControlBinop cBinop_tHF48jcm;
  SignalVarf sVarf_EU9QAWh4;
  ControlVar cVar_nRFUM0Fb;
  ControlVar cVar_fbORZrjg;
  ControlVar cVar_doj7YWZj;
  ControlVar cVar_IdToH0BY;
  ControlIf cIf_bCerdtSk;
  ControlBinop cBinop_yKq3XOcW;
  ControlBinop cBinop_AuoTENys;
  ControlBinop cBinop_mNHSH7be;
  ControlDelay cDelay_5H3yOKr7;
  ControlDelay cDelay_QLeijHiS;
  ControlBinop cBinop_uHByafK6;
  HvTable hTable_GQglguVz;
  ControlBinop cBinop_OXx4XpCM;
  ControlTabhead cTabhead_geCnZB9N;
  ControlVar cVar_3j1Hd02f;
  ControlDelay cDelay_qloyxXUx;
  ControlDelay cDelay_VDKmmky4;
  ControlBinop cBinop_MOV4BC1T;
  ControlBinop cBinop_HBmLO3Jl;
  ControlBinop cBinop_XafsBEiL;
  ControlBinop cBinop_9xlqUdYw;
  ControlBinop cBinop_yJ1M7mOR;
  ControlBinop cBinop_eZ9glY6a;
  ControlDelay cDelay_IDweWNCU;
  ControlDelay cDelay_Cf0oF6Xw;
  ControlBinop cBinop_Ieltx2ym;
  HvTable hTable_aZFTCRSn;
  ControlBinop cBinop_ZdDIlE1m;
  ControlTabhead cTabhead_XPD1MOMq;
  ControlVar cVar_Fg4KlTcY;
  ControlDelay cDelay_3g8AJhfu;
  ControlDelay cDelay_TEbwXFeY;
  ControlBinop cBinop_I06Q2YJq;
  ControlBinop cBinop_ZUrgM17N;
  ControlBinop cBinop_1yIJYxlx;
  ControlBinop cBinop_DXL3GX6R;
  ControlBinop cBinop_utCcG7ep;
  ControlBinop cBinop_YFyAucWf;
  ControlDelay cDelay_kNlymjFX;
  ControlDelay cDelay_q1TN7IBi;
  ControlBinop cBinop_rZNiafct;
  HvTable hTable_mHXkthO2;
  ControlBinop cBinop_UNhlUMVR;
  ControlTabhead cTabhead_qB2wTfG7;
  ControlVar cVar_5enhUL8X;
  ControlDelay cDelay_hEQwcLqc;
  ControlDelay cDelay_LxbCx7gJ;
  ControlBinop cBinop_AqGUiTsy;
  ControlBinop cBinop_DUQ0zlGQ;
  ControlBinop cBinop_dDiM0QuJ;
  ControlBinop cBinop_2t6k5FLc;
  ControlBinop cBinop_6YGnhvH2;
  ControlBinop cBinop_sKhL8BeD;
  ControlDelay cDelay_Db9oMUx0;
  ControlDelay cDelay_Tw4ombWu;
  ControlBinop cBinop_LGOOmd0w;
  HvTable hTable_UsPKnZC4;
  ControlBinop cBinop_BvlAStti;
  ControlTabhead cTabhead_rPaFgR69;
  ControlVar cVar_p83Xy4uz;
  ControlDelay cDelay_EaC6kLKx;
  ControlDelay cDelay_bXeBs3gO;
  ControlBinop cBinop_RsOD759Y;
  ControlBinop cBinop_wmx4KygR;
  ControlBinop cBinop_GUv3N79p;
  ControlBinop cBinop_I1nCJbys;
  ControlBinop cBinop_Ue5CI3Lc;
  ControlBinop cBinop_hCgPSAie;
  ControlDelay cDelay_zQPtTaw6;
  ControlDelay cDelay_lGSDM78E;
  ControlBinop cBinop_99Set3gK;
  HvTable hTable_LWU36yW2;
  ControlBinop cBinop_9LQzEIhf;
  ControlTabhead cTabhead_lwzJdzf0;
  ControlVar cVar_DyEUVPv5;
  ControlDelay cDelay_egrzvyJ8;
  ControlDelay cDelay_cgSrdfzh;
  ControlBinop cBinop_2qj4e2hV;
  ControlBinop cBinop_9HknvAaZ;
  ControlBinop cBinop_TbBC2Tfm;
  ControlBinop cBinop_9UxEqea2;
  ControlBinop cBinop_IEHtG3lO;
  ControlBinop cBinop_YEoTTorX;
  ControlDelay cDelay_ffkdcGZA;
  ControlDelay cDelay_9vXcNQ0j;
  ControlBinop cBinop_6v4mazhT;
  HvTable hTable_rdzKRYQ3;
  ControlBinop cBinop_3jN862jj;
  ControlTabhead cTabhead_hLUIyRXl;
  ControlVar cVar_OrJJ709E;
  ControlDelay cDelay_St1YrJMw;
  ControlDelay cDelay_b6Qs53Zo;
  ControlBinop cBinop_9nzKfAOn;
  ControlBinop cBinop_Bf8rbLL3;
  ControlBinop cBinop_rGnLFc9h;
  ControlBinop cBinop_YWccN7wY;
  ControlBinop cBinop_hl412BBl;
  ControlBinop cBinop_kT2oVM6B;
  ControlVar cVar_McgfNoUb;
  ControlVar cVar_W6DshnkC;
  ControlPack cPack_juuoRfZc;
  ControlVar cVar_1t6nBS8s;
  ControlBinop cBinop_HL13zx6T;
  ControlBinop cBinop_Axux86y9;
  SignalVarf sVarf_gfTtfgFG;
  ControlBinop cBinop_gmBvFW3U;
  ControlBinop cBinop_MjS6xFPF;
  ControlBinop cBinop_t4CsbJhk;
  SignalVarf sVarf_OKf3bfwp;
  ControlVar cVar_9hjrcvcZ;
  ControlBinop cBinop_IqItg1RO;
  ControlBinop cBinop_eSUZ5hmB;
  SignalVarf sVarf_OIto0O7t;
  ControlBinop cBinop_YPKKqxDH;
  ControlBinop cBinop_LBF9KxnU;
  ControlBinop cBinop_VaTvxvmx;
  SignalVarf sVarf_HRwvpPef;
  ControlVar cVar_lmvXltf9;
  ControlBinop cBinop_pwOsg8XW;
  ControlBinop cBinop_axOUjR0o;
  SignalVarf sVarf_ddq82qvS;
  ControlBinop cBinop_CRuICYx9;
  ControlBinop cBinop_aRbdoElY;
  ControlBinop cBinop_UqP158i1;
  SignalVarf sVarf_vc5D4XNY;
  ControlBinop cBinop_mHVtWhxf;
  ControlBinop cBinop_JNu3GXiu;
  ControlBinop cBinop_qFSyqBm1;
  ControlDelay cDelay_plgUpczG;
  ControlVar cVar_ebIsJQMj;
  ControlBinop cBinop_5c8Bnot1;
  ControlBinop cBinop_yFKRsTvl;
  ControlBinop cBinop_CO3z9KXD;
  ControlVar cVar_sUNZH49O;
  ControlVar cVar_MzH7lMij;
  ControlIf cIf_f9JLNq7Y;
  ControlBinop cBinop_E2pSBl7m;
  ControlDelay cDelay_oOYF9uoQ;
  ControlDelay cDelay_QbLvp6u0;
  ControlBinop cBinop_0cs3btJ5;
  HvTable hTable_YAQgNGE6;
  ControlBinop cBinop_p1YnRRZw;
  ControlTabhead cTabhead_Z1pFxwMs;
  ControlVar cVar_9l63ipka;
  ControlDelay cDelay_NWU12N7l;
  ControlDelay cDelay_2BW7oHOw;
  ControlBinop cBinop_rvOwYJK4;
  ControlBinop cBinop_czngRaxr;
  ControlBinop cBinop_OQ8mj4oW;
  ControlBinop cBinop_dkFYJPQy;
  ControlBinop cBinop_5pNXV8N5;
  ControlBinop cBinop_8YPbw2c0;
  ControlVar cVar_7IRwgm6b;
  ControlVar cVar_oyNvYQZF;
  ControlVar cVar_SLSaTluj;
  ControlVar cVar_CoEZQiQL;
  ControlVar cVar_RLY1jNaJ;
  ControlVar cVar_aDYRWDMO;
  ControlIf cIf_A6xMTjV8;
  ControlBinop cBinop_BTOddFVn;
  ControlVar cVar_j9VIuGnh;
  ControlIf cIf_sWCuA4RG;
  ControlBinop cBinop_rPjjoaRE;
  ControlSlice cSlice_eDca5gLV;
  ControlSlice cSlice_vpFP4fCE;
  ControlVar cVar_fCj1R3v7;
  ControlIf cIf_vbU9AHRz;
  ControlBinop cBinop_xt2C0tHQ;
  ControlIf cIf_CVXZj6jJ;
  ControlIf cIf_Wt3lE4fI;
  ControlIf cIf_NhZ8Y9PY;
  ControlIf cIf_ARSQaKva;
  ControlIf cIf_8Y3Co807;
  SignalVarf sVarf_v49UQBa2;
  ControlBinop cBinop_nZPOBpXP;
  ControlBinop cBinop_nvcfzKBr;
  ControlBinop cBinop_zleVGB4M;
  ControlBinop cBinop_lcbEHw2b;
  SignalVarf sVarf_l0EJd1L6;
  ControlBinop cBinop_621r2hdR;
  ControlBinop cBinop_A5fFbub0;
  SignalVarf sVarf_1tf0MkIY;
  SignalVarf sVarf_oskGjInu;
  ControlBinop cBinop_dTPgtWIO;
  ControlBinop cBinop_31ihSQ87;
  ControlBinop cBinop_hTl5rXRZ;
  ControlBinop cBinop_IR0AUejU;
  ControlBinop cBinop_9PUWI8CJ;
  ControlBinop cBinop_9RnwR4Vs;
  ControlBinop cBinop_dNTv7MMJ;
  ControlBinop cBinop_UHMzXVdS;
  ControlBinop cBinop_yqZWGToG;
  ControlBinop cBinop_70xehuI3;
  ControlBinop cBinop_B8buSh8n;
  ControlBinop cBinop_26BKYTzE;
  ControlBinop cBinop_7ETtRdf4;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
