/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_HI3mnHp0, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_tmHAd2VJ);
  numBytes += sLine_init(&sLine_Opn3dCSY);
  numBytes += sTabhead_init(&sTabhead_uUJZmkUt, &hTable_dkAMXtbv);
  numBytes += sTabread_init(&sTabread_wAUzuz1y, &hTable_dkAMXtbv, false);
  numBytes += sTabread_init(&sTabread_Gap3YKaQ, &hTable_dkAMXtbv, false);
  numBytes += sTabhead_init(&sTabhead_90GwjrS1, &hTable_dkAMXtbv);
  numBytes += sTabread_init(&sTabread_VaSkBIkc, &hTable_dkAMXtbv, false);
  numBytes += sTabread_init(&sTabread_6D6eVyGA, &hTable_dkAMXtbv, false);
  numBytes += sTabwrite_init(&sTabwrite_r7MPYTzx, &hTable_dkAMXtbv);
  numBytes += sRPole_init(&sRPole_xu7hceyA);
  numBytes += sDel1_init(&sDel1_Ta73M6F0);
  numBytes += sTabread_init(&sTabread_AO9Dt6Us, &hTable_YAQgNGE6, true);
  numBytes += sTabwrite_init(&sTabwrite_m0F9mjOq, &hTable_YAQgNGE6);
  numBytes += sTabread_init(&sTabread_qD1sV7Me, &hTable_TckizUKh, true);
  numBytes += sRPole_init(&sRPole_qcxPoxe9);
  numBytes += sLine_init(&sLine_IoQu5Bvj);
  numBytes += sLine_init(&sLine_cxHaKAdV);
  numBytes += sTabread_init(&sTabread_iCsspYTK, &hTable_GQglguVz, true);
  numBytes += sTabread_init(&sTabread_PFwPTWKO, &hTable_aZFTCRSn, true);
  numBytes += sTabread_init(&sTabread_qBNCpf9u, &hTable_mHXkthO2, true);
  numBytes += sTabread_init(&sTabread_Cga4SIPa, &hTable_UsPKnZC4, true);
  numBytes += sTabread_init(&sTabread_BMSIfyoq, &hTable_rdzKRYQ3, true);
  numBytes += sTabread_init(&sTabread_SWzBDsf1, &hTable_LWU36yW2, true);
  numBytes += sTabwrite_init(&sTabwrite_8lQcHMil, &hTable_GQglguVz);
  numBytes += sTabwrite_init(&sTabwrite_AjIvwtaR, &hTable_aZFTCRSn);
  numBytes += sTabwrite_init(&sTabwrite_hVWls8Ft, &hTable_mHXkthO2);
  numBytes += sTabwrite_init(&sTabwrite_PMmodRQQ, &hTable_UsPKnZC4);
  numBytes += sTabwrite_init(&sTabwrite_PoZ1RtTs, &hTable_LWU36yW2);
  numBytes += sTabwrite_init(&sTabwrite_65YL1yEJ, &hTable_rdzKRYQ3);
  numBytes += sTabread_init(&sTabread_7vvJkzSJ, &hTable_K7WBBQGI, true);
  numBytes += sRPole_init(&sRPole_EHtjvt45);
  numBytes += sTabread_init(&sTabread_PDOmzqdP, &hTable_mD253U7R, true);
  numBytes += sRPole_init(&sRPole_yDGxBN4w);
  numBytes += sTabread_init(&sTabread_5Y0oTXRm, &hTable_p15j7FMz, true);
  numBytes += sRPole_init(&sRPole_3pAafqwQ);
  numBytes += sTabwrite_init(&sTabwrite_4YgJJoul, &hTable_TckizUKh);
  numBytes += sTabwrite_init(&sTabwrite_fTGzFUHW, &hTable_K7WBBQGI);
  numBytes += sTabwrite_init(&sTabwrite_faKXG8tJ, &hTable_mD253U7R);
  numBytes += sTabwrite_init(&sTabwrite_EBcVXs82, &hTable_p15j7FMz);
  numBytes += sLine_init(&sLine_20hnk4af);
  numBytes += cVar_init_f(&cVar_10JBhDWc, 0.0f);
  numBytes += cVar_init_f(&cVar_mi05ABuW, 0.0f);
  numBytes += cPack_init(&cPack_n4BF6pxL, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_w0xpIJtP, 0.0f);
  numBytes += cPack_init(&cPack_0logVoCA, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_F0r5GMAQ, 0.0f);
  numBytes += cVar_init_f(&cVar_cjl9tWBP, 0.0f);
  numBytes += cDelay_init(this, &cDelay_jLI3YYRH, 0.0f);
  numBytes += cDelay_init(this, &cDelay_5LDOR2ri, 0.0f);
  numBytes += hTable_init(&hTable_dkAMXtbv, 256);
  numBytes += cVar_init_s(&cVar_fxoTl2YJ, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_96BBl98G, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3DxtU3SJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ju40mYCt, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_27i6FdhF, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_JH7sdhMR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lpiJNm31, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZwcNDYLG, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_2vaFFgsO, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_F1JJac0h, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_HX8LSDUE, 0.0f);
  numBytes += cBinop_init(&cBinop_6gfAG3UW, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_eLGq56RT, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_vQrnjZVM, -1347591329);
  numBytes += cSlice_init(&cSlice_QsvmDaXc, 1, 1);
  numBytes += cDelay_init(this, &cDelay_DhEajXR4, 0.0f);
  numBytes += cVar_init_f(&cVar_DcRW0h9x, 5.0f);
  numBytes += cBinop_init(&cBinop_Q8rPxsYk, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_qUsWkknu, &hTable_TckizUKh);
  numBytes += cVar_init_s(&cVar_KImUKwxq, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_IAAcowjL, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_rsLGKoQz, 0.0f);
  numBytes += cBinop_init(&cBinop_m3G5pWcx, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_6iLlKoIa, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_oh60u2TU, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_uTQVDvbs, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_LMSlRzgO, &hTable_K7WBBQGI);
  numBytes += cVar_init_s(&cVar_h8z30s9A, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_2Pmy94e0, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_xHde3dBO, 0.0f);
  numBytes += cBinop_init(&cBinop_dwpgbpJf, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_jqi3Dg6S, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_baroojZs, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_L0Zcmsfy, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_jDcDPxe9, &hTable_mD253U7R);
  numBytes += cVar_init_s(&cVar_dFOcwt4j, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_kxod4KEj, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_UIX0HPEm, 0.0f);
  numBytes += cBinop_init(&cBinop_XMChOPhl, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_vQS1jC73, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_Kj5iUSPy, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_y0z20Uo2, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_JNl44N1c, &hTable_p15j7FMz);
  numBytes += cVar_init_s(&cVar_j7w3qwJV, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_xgQgwo8p, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_YVLoTg64, 0.0f);
  numBytes += cBinop_init(&cBinop_PI3gKktT, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_t7v5Qj8N, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_dkcLWAyC, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_L8vuJXsA, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_JZQIXUjS, 0.0f);
  numBytes += cDelay_init(this, &cDelay_n5KmItgG, 0.0f);
  numBytes += hTable_init(&hTable_TckizUKh, 256);
  numBytes += cDelay_init(this, &cDelay_oxCAhVjZ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_UTsibJnN, 0.0f);
  numBytes += hTable_init(&hTable_K7WBBQGI, 256);
  numBytes += cDelay_init(this, &cDelay_Als21axD, 0.0f);
  numBytes += cDelay_init(this, &cDelay_zCfWwuVx, 0.0f);
  numBytes += hTable_init(&hTable_mD253U7R, 256);
  numBytes += cDelay_init(this, &cDelay_AFdfPvmw, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Qlys6dku, 0.0f);
  numBytes += hTable_init(&hTable_p15j7FMz, 256);
  numBytes += cPack_init(&cPack_05mt9mV8, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_swYOleg7, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_37thxS8c, 22050.0f);
  numBytes += cBinop_init(&cBinop_bqpBZwch, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_XNiR5GyA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EU9QAWh4, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_nRFUM0Fb, 0.0f);
  numBytes += cVar_init_f(&cVar_fbORZrjg, 0.0f);
  numBytes += cVar_init_f(&cVar_doj7YWZj, 0.0f);
  numBytes += cVar_init_f(&cVar_IdToH0BY, 0.0f);
  numBytes += cIf_init(&cIf_bCerdtSk, false);
  numBytes += cDelay_init(this, &cDelay_5H3yOKr7, 0.0f);
  numBytes += cDelay_init(this, &cDelay_QLeijHiS, 0.0f);
  numBytes += hTable_init(&hTable_GQglguVz, 256);
  numBytes += cTabhead_init(&cTabhead_geCnZB9N, &hTable_GQglguVz);
  numBytes += cVar_init_s(&cVar_3j1Hd02f, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_qloyxXUx, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_VDKmmky4, 0.0f);
  numBytes += cBinop_init(&cBinop_MOV4BC1T, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_XafsBEiL, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_9xlqUdYw, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_eZ9glY6a, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_IDweWNCU, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Cf0oF6Xw, 0.0f);
  numBytes += hTable_init(&hTable_aZFTCRSn, 256);
  numBytes += cTabhead_init(&cTabhead_XPD1MOMq, &hTable_aZFTCRSn);
  numBytes += cVar_init_s(&cVar_Fg4KlTcY, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_3g8AJhfu, 25.796f);
  numBytes += cDelay_init(this, &cDelay_TEbwXFeY, 0.0f);
  numBytes += cBinop_init(&cBinop_I06Q2YJq, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_1yIJYxlx, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_DXL3GX6R, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_YFyAucWf, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_kNlymjFX, 0.0f);
  numBytes += cDelay_init(this, &cDelay_q1TN7IBi, 0.0f);
  numBytes += hTable_init(&hTable_mHXkthO2, 256);
  numBytes += cTabhead_init(&cTabhead_qB2wTfG7, &hTable_mHXkthO2);
  numBytes += cVar_init_s(&cVar_5enhUL8X, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_hEQwcLqc, 19.392f);
  numBytes += cDelay_init(this, &cDelay_LxbCx7gJ, 0.0f);
  numBytes += cBinop_init(&cBinop_AqGUiTsy, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_dDiM0QuJ, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_2t6k5FLc, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_sKhL8BeD, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_Db9oMUx0, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Tw4ombWu, 0.0f);
  numBytes += hTable_init(&hTable_UsPKnZC4, 256);
  numBytes += cTabhead_init(&cTabhead_rPaFgR69, &hTable_UsPKnZC4);
  numBytes += cVar_init_s(&cVar_p83Xy4uz, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_EaC6kLKx, 16.364f);
  numBytes += cDelay_init(this, &cDelay_bXeBs3gO, 0.0f);
  numBytes += cBinop_init(&cBinop_RsOD759Y, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_GUv3N79p, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_I1nCJbys, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_hCgPSAie, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_zQPtTaw6, 0.0f);
  numBytes += cDelay_init(this, &cDelay_lGSDM78E, 0.0f);
  numBytes += hTable_init(&hTable_LWU36yW2, 256);
  numBytes += cTabhead_init(&cTabhead_lwzJdzf0, &hTable_LWU36yW2);
  numBytes += cVar_init_s(&cVar_DyEUVPv5, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_egrzvyJ8, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_cgSrdfzh, 0.0f);
  numBytes += cBinop_init(&cBinop_2qj4e2hV, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_TbBC2Tfm, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_9UxEqea2, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_YEoTTorX, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_ffkdcGZA, 0.0f);
  numBytes += cDelay_init(this, &cDelay_9vXcNQ0j, 0.0f);
  numBytes += hTable_init(&hTable_rdzKRYQ3, 256);
  numBytes += cTabhead_init(&cTabhead_hLUIyRXl, &hTable_rdzKRYQ3);
  numBytes += cVar_init_s(&cVar_OrJJ709E, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_St1YrJMw, 7.645f);
  numBytes += cDelay_init(this, &cDelay_b6Qs53Zo, 0.0f);
  numBytes += cBinop_init(&cBinop_9nzKfAOn, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_rGnLFc9h, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_YWccN7wY, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_kT2oVM6B, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_McgfNoUb, 0.0f);
  numBytes += cVar_init_f(&cVar_W6DshnkC, 0.0f);
  numBytes += cPack_init(&cPack_juuoRfZc, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_1t6nBS8s, 22050.0f);
  numBytes += cBinop_init(&cBinop_HL13zx6T, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_gfTtfgFG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OKf3bfwp, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_9hjrcvcZ, 22050.0f);
  numBytes += cBinop_init(&cBinop_IqItg1RO, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_OIto0O7t, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HRwvpPef, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lmvXltf9, 22050.0f);
  numBytes += cBinop_init(&cBinop_pwOsg8XW, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_ddq82qvS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vc5D4XNY, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_plgUpczG, 0.0f);
  numBytes += cVar_init_f(&cVar_ebIsJQMj, 1000.0f);
  numBytes += cBinop_init(&cBinop_CO3z9KXD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_sUNZH49O, 0.0f);
  numBytes += cVar_init_f(&cVar_MzH7lMij, 0.0f);
  numBytes += cIf_init(&cIf_f9JLNq7Y, false);
  numBytes += cDelay_init(this, &cDelay_oOYF9uoQ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_QbLvp6u0, 0.0f);
  numBytes += hTable_init(&hTable_YAQgNGE6, 256);
  numBytes += cTabhead_init(&cTabhead_Z1pFxwMs, &hTable_YAQgNGE6);
  numBytes += cVar_init_s(&cVar_9l63ipka, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_NWU12N7l, 150.0f);
  numBytes += cDelay_init(this, &cDelay_2BW7oHOw, 0.0f);
  numBytes += cBinop_init(&cBinop_rvOwYJK4, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_OQ8mj4oW, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_dkFYJPQy, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_8YPbw2c0, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_7IRwgm6b, 0.0f);
  numBytes += cVar_init_f(&cVar_oyNvYQZF, 0.0f);
  numBytes += cVar_init_f(&cVar_SLSaTluj, 0.0f);
  numBytes += cVar_init_f(&cVar_CoEZQiQL, 0.0f);
  numBytes += cVar_init_f(&cVar_RLY1jNaJ, 0.0f);
  numBytes += cVar_init_f(&cVar_aDYRWDMO, 0.0f);
  numBytes += cIf_init(&cIf_A6xMTjV8, false);
  numBytes += cVar_init_f(&cVar_j9VIuGnh, 0.0f);
  numBytes += cIf_init(&cIf_sWCuA4RG, false);
  numBytes += cSlice_init(&cSlice_eDca5gLV, 1, -1);
  numBytes += cSlice_init(&cSlice_vpFP4fCE, 1, -1);
  numBytes += cVar_init_f(&cVar_fCj1R3v7, 0.0f);
  numBytes += cIf_init(&cIf_vbU9AHRz, false);
  numBytes += cBinop_init(&cBinop_xt2C0tHQ, 0.0f); // __neq
  numBytes += cIf_init(&cIf_CVXZj6jJ, false);
  numBytes += cIf_init(&cIf_Wt3lE4fI, false);
  numBytes += cIf_init(&cIf_NhZ8Y9PY, false);
  numBytes += cIf_init(&cIf_ARSQaKva, true);
  numBytes += cIf_init(&cIf_8Y3Co807, false);
  numBytes += sVarf_init(&sVarf_v49UQBa2, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_zleVGB4M, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_l0EJd1L6, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_621r2hdR, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_A5fFbub0, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_1tf0MkIY, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oskGjInu, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_31ihSQ87, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_yqZWGToG, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_70xehuI3, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_B8buSh8n, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_26BKYTzE, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_7ETtRdf4, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_n4BF6pxL);
  cPack_free(&cPack_0logVoCA);
  hTable_free(&hTable_dkAMXtbv);
  hTable_free(&hTable_TckizUKh);
  hTable_free(&hTable_K7WBBQGI);
  hTable_free(&hTable_mD253U7R);
  hTable_free(&hTable_p15j7FMz);
  cPack_free(&cPack_05mt9mV8);
  cPack_free(&cPack_swYOleg7);
  hTable_free(&hTable_GQglguVz);
  hTable_free(&hTable_aZFTCRSn);
  hTable_free(&hTable_mHXkthO2);
  hTable_free(&hTable_UsPKnZC4);
  hTable_free(&hTable_LWU36yW2);
  hTable_free(&hTable_rdzKRYQ3);
  cPack_free(&cPack_juuoRfZc);
  hTable_free(&hTable_YAQgNGE6);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_dkAMXtbv; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_TckizUKh; // del-1052-del1
    case 0xA2AC524D: return &hTable_K7WBBQGI; // del-1052-del2
    case 0xE36A35B: return &hTable_mD253U7R; // del-1052-del3
    case 0x48CE0509: return &hTable_p15j7FMz; // del-1052-del4
    case 0xE34D6E72: return &hTable_GQglguVz; // del-1052-ref1
    case 0x6A1027AB: return &hTable_aZFTCRSn; // del-1052-ref2
    case 0xA37C6D49: return &hTable_mHXkthO2; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_UsPKnZC4; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_LWU36yW2; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_rdzKRYQ3; // del-1052-ref5
    case 0xED65564F: return &hTable_YAQgNGE6; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HTaslcGu_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XmbBXM5U_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4nIwuM3m_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HE5X18RS_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_buCVE288_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_21FpADwZ_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OAUVfwv1_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SBXfJlGf_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LsT4IpXr_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JLJ7jWWy_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4VdAMdF5_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xITV5XxO_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_U0anIvcf_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5pTHeLHg_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LGIAuMdq_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JC74RZnc_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Dj8R1kiv_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G6acpR5r_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7D72dwu4_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oyHj9GYv_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xaCYwnlR_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4LoD4si4_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_T04VZtaW_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8a2K9Vk6_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_10JBhDWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_QuM31m9v_sendMessage);
}

void Heavy_ChaffVerb::cVar_mi05ABuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_4iYFbmSv_sendMessage);
}

void Heavy_ChaffVerb::cPack_n4BF6pxL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_tmHAd2VJ, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_P6vEfGhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w0xpIJtP, 0, m, &cVar_w0xpIJtP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DW425XPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_P6vEfGhQ_sendMessage);
}

void Heavy_ChaffVerb::cVar_w0xpIJtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_eD8bTLaC_sendMessage);
}

void Heavy_ChaffVerb::cPack_0logVoCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_Opn3dCSY, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_F0r5GMAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_Dk5ra3aj_sendMessage);
}

void Heavy_ChaffVerb::cVar_cjl9tWBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_HI3mnHp0, 0, m);
}

void Heavy_ChaffVerb::cMsg_6Hkq6sZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aiWMVMZY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_aiWMVMZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_k5uzdX23_sendMessage);
}

void Heavy_ChaffVerb::cDelay_jLI3YYRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jLI3YYRH, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5LDOR2ri, 0, m, &cDelay_5LDOR2ri_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jLI3YYRH, 0, m, &cDelay_jLI3YYRH_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_r7MPYTzx, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_5LDOR2ri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5LDOR2ri, m);
  cMsg_Ryot0aI5_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_LmDBva4o_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_UCnFb2Id_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_VTTufTcz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wnVkXYpY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_dkAMXtbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I8UUNqz6_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jLI3YYRH, 2, m, &cDelay_jLI3YYRH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8Bs80l57_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wnVkXYpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_dkAMXtbv, 0, m, &hTable_dkAMXtbv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_k5uzdX23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_VTTufTcz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Ryot0aI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_dkAMXtbv, 0, m, &hTable_dkAMXtbv_sendMessage);
}

void Heavy_ChaffVerb::cCast_8Bs80l57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jLI3YYRH, 0, m, &cDelay_jLI3YYRH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_I8UUNqz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_5LDOR2ri, 2, m, &cDelay_5LDOR2ri_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UCnFb2Id_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_r7MPYTzx, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_xBQCMwnL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GougMyTr_sendMessage);
}

void Heavy_ChaffVerb::cSystem_GougMyTr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_IZkHshLi_sendMessage);
}

void Heavy_ChaffVerb::cVar_fxoTl2YJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sVQ0VCIJ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_GkmxeHu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_TvrjxELk_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_96BBl98G, m);
}

void Heavy_ChaffVerb::cBinop_IZkHshLi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_3DxtU3SJ, m);
}

void Heavy_ChaffVerb::cMsg_sVQ0VCIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_GkmxeHu0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TvrjxELk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ju40mYCt, m);
}

void Heavy_ChaffVerb::cMsg_vL3T3KKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_i4NDtaTG_sendMessage);
}

void Heavy_ChaffVerb::cSystem_i4NDtaTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_oqtVp36k_sendMessage);
}

void Heavy_ChaffVerb::cVar_27i6FdhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rNp03cbH_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_Vt26Mh4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_kqUDIQdt_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_JH7sdhMR, m);
}

void Heavy_ChaffVerb::cBinop_oqtVp36k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_lpiJNm31, m);
}

void Heavy_ChaffVerb::cMsg_rNp03cbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Vt26Mh4Y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kqUDIQdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ZwcNDYLG, m);
}

void Heavy_ChaffVerb::cBinop_2vaFFgsO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cjl9tWBP, 0, m, &cVar_cjl9tWBP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BJIm95Ky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GSZTlf6E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vnZR2RDK_sendMessage);
}

void Heavy_ChaffVerb::cCast_vnZR2RDK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2vaFFgsO, HV_BINOP_DIVIDE, 0, m, &cBinop_2vaFFgsO_sendMessage);
}

void Heavy_ChaffVerb::cCast_GSZTlf6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2vaFFgsO, HV_BINOP_DIVIDE, 1, m, &cBinop_2vaFFgsO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eD8bTLaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BsP1RD6n_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QuM31m9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_DW425XPq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BsP1RD6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2vaFFgsO, HV_BINOP_DIVIDE, 0, m, &cBinop_2vaFFgsO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Dk5ra3aj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_0logVoCA, 0, m, &cPack_0logVoCA_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4iYFbmSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_BJIm95Ky_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_n4BF6pxL, 0, m, &cPack_n4BF6pxL_sendMessage);
}

void Heavy_ChaffVerb::cUnop_E4VmHeA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wt3lE4fI, 0, m, &cIf_Wt3lE4fI_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_j8he2tA3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jP7uM3XJ_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PYyxWNyZ_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k2Rs6x7w_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_jP7uM3XJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_05OKFJ5s_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_PYyxWNyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xnICDC5J_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_k2Rs6x7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GWFr8rlL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_feweOHvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_siiVy1ry_sendMessage);
}

void Heavy_ChaffVerb::cBinop_siiVy1ry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_SGEW7P5V_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_KCCAKbVA_sendMessage);
}

void Heavy_ChaffVerb::cVar_HX8LSDUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_wbxjTEd3_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lWVhP7oF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_8hcgXIs6_sendMessage);
}

void Heavy_ChaffVerb::cSystem_8hcgXIs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6gfAG3UW, HV_BINOP_DIVIDE, 1, m, &cBinop_6gfAG3UW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SGEW7P5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rkgLh275_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rkgLh275_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_eLGq56RT, m);
}

void Heavy_ChaffVerb::cMsg_xnZQ0DMS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_37KoMZuC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_37KoMZuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_feweOHvU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_KCCAKbVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_F1JJac0h, m);
}

void Heavy_ChaffVerb::cBinop_wbxjTEd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_7nR9z8Mc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7nR9z8Mc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6gfAG3UW, HV_BINOP_DIVIDE, 0, m, &cBinop_6gfAG3UW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6gfAG3UW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xnZQ0DMS_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_flQRvxuy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QsvmDaXc, 0, m, &cSlice_QsvmDaXc_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_vQrnjZVM, 0, m, &cRandom_vQrnjZVM_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_hiXztmuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_unX49ARY_sendMessage);
}

void Heavy_ChaffVerb::cUnop_unX49ARY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_nvcfzKBr_sendMessage);
}

void Heavy_ChaffVerb::cRandom_vQrnjZVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_hiXztmuM_sendMessage);
}

void Heavy_ChaffVerb::cSlice_QsvmDaXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_vQrnjZVM, 1, m, &cRandom_vQrnjZVM_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_Ov4weLRk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_rIYcNqc9_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_rIYcNqc9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B05Mm9rM_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_DhEajXR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DhEajXR4, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DhEajXR4, 0, m, &cDelay_DhEajXR4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sUNZH49O, 0, m, &cVar_sUNZH49O_sendMessage);
}

void Heavy_ChaffVerb::cCast_B05Mm9rM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rIYcNqc9_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_DhEajXR4, 0, m, &cDelay_DhEajXR4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sUNZH49O, 0, m, &cVar_sUNZH49O_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AP5Fzc8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zz2TLNtg_sendMessage);
}

void Heavy_ChaffVerb::cSystem_zz2TLNtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_b2jSOW6B_sendMessage);
}

void Heavy_ChaffVerb::cVar_DcRW0h9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q8rPxsYk, HV_BINOP_MULTIPLY, 0, m, &cBinop_Q8rPxsYk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rIYcNqc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_DhEajXR4, 0, m, &cDelay_DhEajXR4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1hRGgDDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DhEajXR4, 2, m, &cDelay_DhEajXR4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_b2jSOW6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q8rPxsYk, HV_BINOP_MULTIPLY, 1, m, &cBinop_Q8rPxsYk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Q8rPxsYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_1hRGgDDW_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_qUsWkknu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6iLlKoIa, HV_BINOP_SUBTRACT, 0, m, &cBinop_6iLlKoIa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IJgtsQPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_j4BGTUgG_sendMessage);
}

void Heavy_ChaffVerb::cSystem_j4BGTUgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_SaUklO7Y_sendMessage);
}

void Heavy_ChaffVerb::cVar_KImUKwxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n5DSBEhj_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_IAAcowjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IAAcowjL, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rsLGKoQz, 0, m, &cDelay_rsLGKoQz_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qD1sV7Me, 0, m, &sTabread_qD1sV7Me_sendMessage);
}

void Heavy_ChaffVerb::cDelay_rsLGKoQz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rsLGKoQz, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qD1sV7Me, 0, m, &sTabread_qD1sV7Me_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rsLGKoQz, 0, m, &cDelay_rsLGKoQz_sendMessage);
}

void Heavy_ChaffVerb::sTabread_qD1sV7Me_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_uTQVDvbs, HV_BINOP_SUBTRACT, 0, m, &cBinop_uTQVDvbs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_m3G5pWcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oh60u2TU, HV_BINOP_MAX, 0, m, &cBinop_oh60u2TU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SaUklO7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m3G5pWcx, HV_BINOP_MULTIPLY, 0, m, &cBinop_m3G5pWcx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6iLlKoIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GI8c33w7_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qD1sV7Me, 0, m, &sTabread_qD1sV7Me_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vbMlTHLs_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Xfy7u8Ct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uTQVDvbs, HV_BINOP_SUBTRACT, 1, m, &cBinop_uTQVDvbs_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rsLGKoQz, 2, m, &cDelay_rsLGKoQz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_n5DSBEhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Xfy7u8Ct_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GI8c33w7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IAAcowjL, 0, m, &cDelay_IAAcowjL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rsLGKoQz, 0, m, &cDelay_rsLGKoQz_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lkd1eUjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_oh60u2TU, HV_BINOP_MAX, 1, m, &cBinop_oh60u2TU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oh60u2TU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6iLlKoIa, HV_BINOP_SUBTRACT, 1, m, &cBinop_6iLlKoIa_sendMessage);
}

void Heavy_ChaffVerb::cCast_vbMlTHLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IAAcowjL, 0, m, &cDelay_IAAcowjL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IRV9bTmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IAAcowjL, 2, m, &cDelay_IAAcowjL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_uTQVDvbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_IRV9bTmd_sendMessage);
}

void Heavy_ChaffVerb::cCast_qg1DNFKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KImUKwxq, 0, m, &cVar_KImUKwxq_sendMessage);
  cMsg_IJgtsQPi_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_qUsWkknu, 0, m, &cTabhead_qUsWkknu_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_LMSlRzgO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jqi3Dg6S, HV_BINOP_SUBTRACT, 0, m, &cBinop_jqi3Dg6S_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xFCf5AHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nlmFnosH_sendMessage);
}

void Heavy_ChaffVerb::cSystem_nlmFnosH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_kNY7zYZd_sendMessage);
}

void Heavy_ChaffVerb::cVar_h8z30s9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5uTujj8k_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_2Pmy94e0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2Pmy94e0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xHde3dBO, 0, m, &cDelay_xHde3dBO_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_7vvJkzSJ, 0, m, &sTabread_7vvJkzSJ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_xHde3dBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xHde3dBO, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_7vvJkzSJ, 0, m, &sTabread_7vvJkzSJ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xHde3dBO, 0, m, &cDelay_xHde3dBO_sendMessage);
}

void Heavy_ChaffVerb::sTabread_7vvJkzSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_L0Zcmsfy, HV_BINOP_SUBTRACT, 0, m, &cBinop_L0Zcmsfy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_dwpgbpJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_baroojZs, HV_BINOP_MAX, 0, m, &cBinop_baroojZs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kNY7zYZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dwpgbpJf, HV_BINOP_MULTIPLY, 0, m, &cBinop_dwpgbpJf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_jqi3Dg6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XS55EPHY_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_7vvJkzSJ, 0, m, &sTabread_7vvJkzSJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RzajhNHz_sendMessage);
}

void Heavy_ChaffVerb::cSystem_lRohbuIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L0Zcmsfy, HV_BINOP_SUBTRACT, 1, m, &cBinop_L0Zcmsfy_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xHde3dBO, 2, m, &cDelay_xHde3dBO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5uTujj8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lRohbuIL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XS55EPHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2Pmy94e0, 0, m, &cDelay_2Pmy94e0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xHde3dBO, 0, m, &cDelay_xHde3dBO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pG1N2APW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_baroojZs, HV_BINOP_MAX, 1, m, &cBinop_baroojZs_sendMessage);
}

void Heavy_ChaffVerb::cBinop_baroojZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jqi3Dg6S, HV_BINOP_SUBTRACT, 1, m, &cBinop_jqi3Dg6S_sendMessage);
}

void Heavy_ChaffVerb::cCast_RzajhNHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2Pmy94e0, 0, m, &cDelay_2Pmy94e0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xTbTvziQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2Pmy94e0, 2, m, &cDelay_2Pmy94e0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_L0Zcmsfy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xTbTvziQ_sendMessage);
}

void Heavy_ChaffVerb::cCast_w4d2Fotm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_h8z30s9A, 0, m, &cVar_h8z30s9A_sendMessage);
  cMsg_xFCf5AHG_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_LMSlRzgO, 0, m, &cTabhead_LMSlRzgO_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_jDcDPxe9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vQS1jC73, HV_BINOP_SUBTRACT, 0, m, &cBinop_vQS1jC73_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ldE8n61I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dd5dy3oX_sendMessage);
}

void Heavy_ChaffVerb::cSystem_dd5dy3oX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ni9LAMmo_sendMessage);
}

void Heavy_ChaffVerb::cVar_dFOcwt4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9U3eIGig_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_kxod4KEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kxod4KEj, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UIX0HPEm, 0, m, &cDelay_UIX0HPEm_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PDOmzqdP, 0, m, &sTabread_PDOmzqdP_sendMessage);
}

void Heavy_ChaffVerb::cDelay_UIX0HPEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UIX0HPEm, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PDOmzqdP, 0, m, &sTabread_PDOmzqdP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UIX0HPEm, 0, m, &cDelay_UIX0HPEm_sendMessage);
}

void Heavy_ChaffVerb::sTabread_PDOmzqdP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_y0z20Uo2, HV_BINOP_SUBTRACT, 0, m, &cBinop_y0z20Uo2_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_XMChOPhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kj5iUSPy, HV_BINOP_MAX, 0, m, &cBinop_Kj5iUSPy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ni9LAMmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XMChOPhl, HV_BINOP_MULTIPLY, 0, m, &cBinop_XMChOPhl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vQS1jC73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1DFqjhcg_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PDOmzqdP, 0, m, &sTabread_PDOmzqdP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UIurLTxh_sendMessage);
}

void Heavy_ChaffVerb::cSystem_mrbnE00s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y0z20Uo2, HV_BINOP_SUBTRACT, 1, m, &cBinop_y0z20Uo2_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UIX0HPEm, 2, m, &cDelay_UIX0HPEm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9U3eIGig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mrbnE00s_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1DFqjhcg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_kxod4KEj, 0, m, &cDelay_kxod4KEj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UIX0HPEm, 0, m, &cDelay_UIX0HPEm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_DJmFJZif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kj5iUSPy, HV_BINOP_MAX, 1, m, &cBinop_Kj5iUSPy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Kj5iUSPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vQS1jC73, HV_BINOP_SUBTRACT, 1, m, &cBinop_vQS1jC73_sendMessage);
}

void Heavy_ChaffVerb::cCast_UIurLTxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kxod4KEj, 0, m, &cDelay_kxod4KEj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_McZVFKsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kxod4KEj, 2, m, &cDelay_kxod4KEj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_y0z20Uo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_McZVFKsU_sendMessage);
}

void Heavy_ChaffVerb::cCast_pWc7dupO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dFOcwt4j, 0, m, &cVar_dFOcwt4j_sendMessage);
  cMsg_ldE8n61I_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_jDcDPxe9, 0, m, &cTabhead_jDcDPxe9_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_JNl44N1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t7v5Qj8N, HV_BINOP_SUBTRACT, 0, m, &cBinop_t7v5Qj8N_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GLCYTS09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_m3M4bFrI_sendMessage);
}

void Heavy_ChaffVerb::cSystem_m3M4bFrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5Wr9OEUS_sendMessage);
}

void Heavy_ChaffVerb::cVar_j7w3qwJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6HTyPduT_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_xgQgwo8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xgQgwo8p, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YVLoTg64, 0, m, &cDelay_YVLoTg64_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5Y0oTXRm, 0, m, &sTabread_5Y0oTXRm_sendMessage);
}

void Heavy_ChaffVerb::cDelay_YVLoTg64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YVLoTg64, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5Y0oTXRm, 0, m, &sTabread_5Y0oTXRm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YVLoTg64, 0, m, &cDelay_YVLoTg64_sendMessage);
}

void Heavy_ChaffVerb::sTabread_5Y0oTXRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_L8vuJXsA, HV_BINOP_SUBTRACT, 0, m, &cBinop_L8vuJXsA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_PI3gKktT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dkcLWAyC, HV_BINOP_MAX, 0, m, &cBinop_dkcLWAyC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5Wr9OEUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PI3gKktT, HV_BINOP_MULTIPLY, 0, m, &cBinop_PI3gKktT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_t7v5Qj8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RSuaxvkG_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5Y0oTXRm, 0, m, &sTabread_5Y0oTXRm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DY7GRYah_sendMessage);
}

void Heavy_ChaffVerb::cSystem_NPXxjbUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L8vuJXsA, HV_BINOP_SUBTRACT, 1, m, &cBinop_L8vuJXsA_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YVLoTg64, 2, m, &cDelay_YVLoTg64_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6HTyPduT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NPXxjbUR_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RSuaxvkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xgQgwo8p, 0, m, &cDelay_xgQgwo8p_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_YVLoTg64, 0, m, &cDelay_YVLoTg64_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TvIcJxyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_dkcLWAyC, HV_BINOP_MAX, 1, m, &cBinop_dkcLWAyC_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dkcLWAyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_t7v5Qj8N, HV_BINOP_SUBTRACT, 1, m, &cBinop_t7v5Qj8N_sendMessage);
}

void Heavy_ChaffVerb::cCast_DY7GRYah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xgQgwo8p, 0, m, &cDelay_xgQgwo8p_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1Z8zp1GM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xgQgwo8p, 2, m, &cDelay_xgQgwo8p_sendMessage);
}

void Heavy_ChaffVerb::cBinop_L8vuJXsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1Z8zp1GM_sendMessage);
}

void Heavy_ChaffVerb::cCast_taIOFxs5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j7w3qwJV, 0, m, &cVar_j7w3qwJV_sendMessage);
  cMsg_GLCYTS09_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JNl44N1c, 0, m, &cTabhead_JNl44N1c_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WDN0LzUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_B79UZDtn_sendMessage);
}

void Heavy_ChaffVerb::cSystem_B79UZDtn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_SnbaHZMy_sendMessage);
}

void Heavy_ChaffVerb::cDelay_JZQIXUjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JZQIXUjS, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_n5KmItgG, 0, m, &cDelay_n5KmItgG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JZQIXUjS, 0, m, &cDelay_JZQIXUjS_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4YgJJoul, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_n5KmItgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_n5KmItgG, m);
  cMsg_RksrUQJe_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_EPBZpCCD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_cNSHQEQk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_7QQ8Wb3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gEiUtrsV_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_TckizUKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wCNPU8QG_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_JZQIXUjS, 2, m, &cDelay_JZQIXUjS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qPMuZSMP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gEiUtrsV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_TckizUKh, 0, m, &hTable_TckizUKh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SnbaHZMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_7QQ8Wb3a_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RksrUQJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_TckizUKh, 0, m, &hTable_TckizUKh_sendMessage);
}

void Heavy_ChaffVerb::cCast_qPMuZSMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JZQIXUjS, 0, m, &cDelay_JZQIXUjS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wCNPU8QG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_n5KmItgG, 2, m, &cDelay_n5KmItgG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cNSHQEQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_4YgJJoul, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_O9B4Guaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vFhA4tyn_sendMessage);
}

void Heavy_ChaffVerb::cSystem_vFhA4tyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_QleszN3Z_sendMessage);
}

void Heavy_ChaffVerb::cDelay_oxCAhVjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oxCAhVjZ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_UTsibJnN, 0, m, &cDelay_UTsibJnN_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oxCAhVjZ, 0, m, &cDelay_oxCAhVjZ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_fTGzFUHW, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_UTsibJnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UTsibJnN, m);
  cMsg_rnL4OEi6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_dqiG0j9F_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_W7o7EUp7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_O54WzMEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x58BOiPW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_K7WBBQGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_py2ep6Dk_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oxCAhVjZ, 2, m, &cDelay_oxCAhVjZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RajJekQm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_x58BOiPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_K7WBBQGI, 0, m, &hTable_K7WBBQGI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QleszN3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_O54WzMEl_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rnL4OEi6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_K7WBBQGI, 0, m, &hTable_K7WBBQGI_sendMessage);
}

void Heavy_ChaffVerb::cCast_RajJekQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oxCAhVjZ, 0, m, &cDelay_oxCAhVjZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_py2ep6Dk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_UTsibJnN, 2, m, &cDelay_UTsibJnN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_W7o7EUp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_fTGzFUHW, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_Zwjnzep5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xl7X1u47_sendMessage);
}

void Heavy_ChaffVerb::cSystem_xl7X1u47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ey7KTSaV_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Als21axD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Als21axD, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zCfWwuVx, 0, m, &cDelay_zCfWwuVx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Als21axD, 0, m, &cDelay_Als21axD_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_faKXG8tJ, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_zCfWwuVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zCfWwuVx, m);
  cMsg_CC5zyJ8N_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_CLAuVHuF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_GDsnoZ65_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_8UdKbgql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IUccEDc8_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_mD253U7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lNCSRxRk_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Als21axD, 2, m, &cDelay_Als21axD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5JU08Ra6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IUccEDc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_mD253U7R, 0, m, &hTable_mD253U7R_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ey7KTSaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_8UdKbgql_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CC5zyJ8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_mD253U7R, 0, m, &hTable_mD253U7R_sendMessage);
}

void Heavy_ChaffVerb::cCast_5JU08Ra6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Als21axD, 0, m, &cDelay_Als21axD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lNCSRxRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_zCfWwuVx, 2, m, &cDelay_zCfWwuVx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GDsnoZ65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_faKXG8tJ, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_DTAV57HN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hj2Q872v_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hj2Q872v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_wQb8froX_sendMessage);
}

void Heavy_ChaffVerb::cDelay_AFdfPvmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AFdfPvmw, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qlys6dku, 0, m, &cDelay_Qlys6dku_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AFdfPvmw, 0, m, &cDelay_AFdfPvmw_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_EBcVXs82, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_Qlys6dku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Qlys6dku, m);
  cMsg_UQobvX5G_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_YgGVYxl0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_fCmcyYgU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_pMWNNzN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pwNxxn7m_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_p15j7FMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sTsgaN9N_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_AFdfPvmw, 2, m, &cDelay_AFdfPvmw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qc5wcUqt_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pwNxxn7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_p15j7FMz, 0, m, &hTable_p15j7FMz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wQb8froX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_pMWNNzN5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UQobvX5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_p15j7FMz, 0, m, &hTable_p15j7FMz_sendMessage);
}

void Heavy_ChaffVerb::cCast_qc5wcUqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AFdfPvmw, 0, m, &cDelay_AFdfPvmw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sTsgaN9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Qlys6dku, 2, m, &cDelay_Qlys6dku_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fCmcyYgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_EBcVXs82, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_05mt9mV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_20hnk4af, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_swYOleg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_cxHaKAdV, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_1wWxIvmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_cTHcv3Wf_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cTHcv3Wf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_mHVtWhxf_sendMessage);
}

void Heavy_ChaffVerb::cVar_37thxS8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bqpBZwch, HV_BINOP_MULTIPLY, 0, m, &cBinop_bqpBZwch_sendMessage);
}

void Heavy_ChaffVerb::cMsg_nShWxKUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qBkcp5k7_sendMessage);
}

void Heavy_ChaffVerb::cSystem_qBkcp5k7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kfjbsqKY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_bqpBZwch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_2ZqkcuqP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SVioVDmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bqpBZwch, HV_BINOP_MULTIPLY, 1, m, &cBinop_bqpBZwch_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kfjbsqKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SVioVDmI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2ZqkcuqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_JNxh1nnY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JNxh1nnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_tHF48jcm_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_EU9QAWh4, m);
}

void Heavy_ChaffVerb::cBinop_tHF48jcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XNiR5GyA, m);
}

void Heavy_ChaffVerb::cVar_nRFUM0Fb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_qFSyqBm1_sendMessage);
}

void Heavy_ChaffVerb::cVar_fbORZrjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_1wWxIvmP_sendMessage);
}

void Heavy_ChaffVerb::cVar_doj7YWZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_yKq3XOcW_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_bCerdtSk, 0, m, &cIf_bCerdtSk_sendMessage);
}

void Heavy_ChaffVerb::cVar_IdToH0BY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_AuoTENys_sendMessage);
}

void Heavy_ChaffVerb::cIf_bCerdtSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_CQ2i70mZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_McgfNoUb, 0, m, &cVar_McgfNoUb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_yKq3XOcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bCerdtSk, 1, m, &cIf_bCerdtSk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_AuoTENys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_mNHSH7be_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mNHSH7be_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_W6DshnkC, 0, m, &cVar_W6DshnkC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GbfVv4Yt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7Q8UwBNs_sendMessage);
}

void Heavy_ChaffVerb::cSystem_7Q8UwBNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_OXx4XpCM_sendMessage);
}

void Heavy_ChaffVerb::cDelay_5H3yOKr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5H3yOKr7, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QLeijHiS, 0, m, &cDelay_QLeijHiS_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5H3yOKr7, 0, m, &cDelay_5H3yOKr7_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8lQcHMil, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_QLeijHiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QLeijHiS, m);
  cMsg_AOYySgeR_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_JqqmszrS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_fH0M4FET_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_uHByafK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gM0TTDPr_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_GQglguVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_apht3gib_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5H3yOKr7, 2, m, &cDelay_5H3yOKr7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dRvw6hfr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gM0TTDPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_GQglguVz, 0, m, &hTable_GQglguVz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OXx4XpCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_uHByafK6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AOYySgeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_GQglguVz, 0, m, &hTable_GQglguVz_sendMessage);
}

void Heavy_ChaffVerb::cCast_dRvw6hfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5H3yOKr7, 0, m, &cDelay_5H3yOKr7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_apht3gib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_QLeijHiS, 2, m, &cDelay_QLeijHiS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fH0M4FET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_8lQcHMil, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_geCnZB9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XafsBEiL, HV_BINOP_SUBTRACT, 0, m, &cBinop_XafsBEiL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PLvwRt3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VK6KxGIy_sendMessage);
}

void Heavy_ChaffVerb::cSystem_VK6KxGIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HBmLO3Jl_sendMessage);
}

void Heavy_ChaffVerb::cVar_3j1Hd02f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vY7MyGaq_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_qloyxXUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qloyxXUx, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VDKmmky4, 0, m, &cDelay_VDKmmky4_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_iCsspYTK, 0, m, &sTabread_iCsspYTK_sendMessage);
}

void Heavy_ChaffVerb::cDelay_VDKmmky4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VDKmmky4, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_iCsspYTK, 0, m, &sTabread_iCsspYTK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VDKmmky4, 0, m, &cDelay_VDKmmky4_sendMessage);
}

void Heavy_ChaffVerb::sTabread_iCsspYTK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_eZ9glY6a, HV_BINOP_SUBTRACT, 0, m, &cBinop_eZ9glY6a_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_MOV4BC1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9xlqUdYw, HV_BINOP_MAX, 0, m, &cBinop_9xlqUdYw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HBmLO3Jl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MOV4BC1T, HV_BINOP_MULTIPLY, 0, m, &cBinop_MOV4BC1T_sendMessage);
}

void Heavy_ChaffVerb::cBinop_XafsBEiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r9FuqQeq_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_iCsspYTK, 0, m, &sTabread_iCsspYTK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GTBNgwzw_sendMessage);
}

void Heavy_ChaffVerb::cSystem_VBlee2b5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eZ9glY6a, HV_BINOP_SUBTRACT, 1, m, &cBinop_eZ9glY6a_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VDKmmky4, 2, m, &cDelay_VDKmmky4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vY7MyGaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_VBlee2b5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_r9FuqQeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qloyxXUx, 0, m, &cDelay_qloyxXUx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VDKmmky4, 0, m, &cDelay_VDKmmky4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LlGrDop6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_9xlqUdYw, HV_BINOP_MAX, 1, m, &cBinop_9xlqUdYw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9xlqUdYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XafsBEiL, HV_BINOP_SUBTRACT, 1, m, &cBinop_XafsBEiL_sendMessage);
}

void Heavy_ChaffVerb::cCast_GTBNgwzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qloyxXUx, 0, m, &cDelay_qloyxXUx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yJ1M7mOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qloyxXUx, 2, m, &cDelay_qloyxXUx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eZ9glY6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_yJ1M7mOR_sendMessage);
}

void Heavy_ChaffVerb::cCast_LJk7muXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3j1Hd02f, 0, m, &cVar_3j1Hd02f_sendMessage);
  cMsg_PLvwRt3y_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_geCnZB9N, 0, m, &cTabhead_geCnZB9N_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Ki142gGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_HiFfzFR1_sendMessage);
}

void Heavy_ChaffVerb::cSystem_HiFfzFR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ZdDIlE1m_sendMessage);
}

void Heavy_ChaffVerb::cDelay_IDweWNCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IDweWNCU, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cf0oF6Xw, 0, m, &cDelay_Cf0oF6Xw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IDweWNCU, 0, m, &cDelay_IDweWNCU_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_AjIvwtaR, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_Cf0oF6Xw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Cf0oF6Xw, m);
  cMsg_r7FXHQmj_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_uErxmGS5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_sb9IinVk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_Ieltx2ym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EIQXuMC3_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_aZFTCRSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tAsheEp2_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IDweWNCU, 2, m, &cDelay_IDweWNCU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CGjsKKYy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_EIQXuMC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_aZFTCRSn, 0, m, &hTable_aZFTCRSn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZdDIlE1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_Ieltx2ym_sendMessage);
}

void Heavy_ChaffVerb::cMsg_r7FXHQmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_aZFTCRSn, 0, m, &hTable_aZFTCRSn_sendMessage);
}

void Heavy_ChaffVerb::cCast_CGjsKKYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IDweWNCU, 0, m, &cDelay_IDweWNCU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tAsheEp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Cf0oF6Xw, 2, m, &cDelay_Cf0oF6Xw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sb9IinVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_AjIvwtaR, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_XPD1MOMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1yIJYxlx, HV_BINOP_SUBTRACT, 0, m, &cBinop_1yIJYxlx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FhtSHxc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_C4m1GjIC_sendMessage);
}

void Heavy_ChaffVerb::cSystem_C4m1GjIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ZUrgM17N_sendMessage);
}

void Heavy_ChaffVerb::cVar_Fg4KlTcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FfLMXHnI_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_3g8AJhfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3g8AJhfu, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TEbwXFeY, 0, m, &cDelay_TEbwXFeY_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PFwPTWKO, 0, m, &sTabread_PFwPTWKO_sendMessage);
}

void Heavy_ChaffVerb::cDelay_TEbwXFeY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TEbwXFeY, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PFwPTWKO, 0, m, &sTabread_PFwPTWKO_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TEbwXFeY, 0, m, &cDelay_TEbwXFeY_sendMessage);
}

void Heavy_ChaffVerb::sTabread_PFwPTWKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_YFyAucWf, HV_BINOP_SUBTRACT, 0, m, &cBinop_YFyAucWf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_I06Q2YJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DXL3GX6R, HV_BINOP_MAX, 0, m, &cBinop_DXL3GX6R_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZUrgM17N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I06Q2YJq, HV_BINOP_MULTIPLY, 0, m, &cBinop_I06Q2YJq_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1yIJYxlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xWnRLA4o_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_PFwPTWKO, 0, m, &sTabread_PFwPTWKO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ODgrrtJx_sendMessage);
}

void Heavy_ChaffVerb::cSystem_4GYOB3DO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YFyAucWf, HV_BINOP_SUBTRACT, 1, m, &cBinop_YFyAucWf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TEbwXFeY, 2, m, &cDelay_TEbwXFeY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FfLMXHnI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_4GYOB3DO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xWnRLA4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3g8AJhfu, 0, m, &cDelay_3g8AJhfu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_TEbwXFeY, 0, m, &cDelay_TEbwXFeY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JuJFHtJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_DXL3GX6R, HV_BINOP_MAX, 1, m, &cBinop_DXL3GX6R_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DXL3GX6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1yIJYxlx, HV_BINOP_SUBTRACT, 1, m, &cBinop_1yIJYxlx_sendMessage);
}

void Heavy_ChaffVerb::cCast_ODgrrtJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3g8AJhfu, 0, m, &cDelay_3g8AJhfu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_utCcG7ep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3g8AJhfu, 2, m, &cDelay_3g8AJhfu_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YFyAucWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_utCcG7ep_sendMessage);
}

void Heavy_ChaffVerb::cCast_9TyClUkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Fg4KlTcY, 0, m, &cVar_Fg4KlTcY_sendMessage);
  cMsg_FhtSHxc4_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_XPD1MOMq, 0, m, &cTabhead_XPD1MOMq_sendMessage);
}

void Heavy_ChaffVerb::cMsg_331nt2nF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JpJAEayl_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JpJAEayl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_UNhlUMVR_sendMessage);
}

void Heavy_ChaffVerb::cDelay_kNlymjFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_kNlymjFX, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_q1TN7IBi, 0, m, &cDelay_q1TN7IBi_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kNlymjFX, 0, m, &cDelay_kNlymjFX_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_hVWls8Ft, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_q1TN7IBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_q1TN7IBi, m);
  cMsg_p1Y1gRe0_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_DhELYRGe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ucGjqHaA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_rZNiafct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CCXQBmnY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_mHXkthO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VssTYBWc_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_kNlymjFX, 2, m, &cDelay_kNlymjFX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rTrzRH0h_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CCXQBmnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_mHXkthO2, 0, m, &hTable_mHXkthO2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UNhlUMVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_rZNiafct_sendMessage);
}

void Heavy_ChaffVerb::cMsg_p1Y1gRe0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_mHXkthO2, 0, m, &hTable_mHXkthO2_sendMessage);
}

void Heavy_ChaffVerb::cCast_rTrzRH0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_kNlymjFX, 0, m, &cDelay_kNlymjFX_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VssTYBWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_q1TN7IBi, 2, m, &cDelay_q1TN7IBi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ucGjqHaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_hVWls8Ft, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_qB2wTfG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dDiM0QuJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_dDiM0QuJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2PPPyVsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ST937eep_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ST937eep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_DUQ0zlGQ_sendMessage);
}

void Heavy_ChaffVerb::cVar_5enhUL8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jxF4dIUk_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_hEQwcLqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hEQwcLqc, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LxbCx7gJ, 0, m, &cDelay_LxbCx7gJ_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qBNCpf9u, 0, m, &sTabread_qBNCpf9u_sendMessage);
}

void Heavy_ChaffVerb::cDelay_LxbCx7gJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LxbCx7gJ, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qBNCpf9u, 0, m, &sTabread_qBNCpf9u_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LxbCx7gJ, 0, m, &cDelay_LxbCx7gJ_sendMessage);
}

void Heavy_ChaffVerb::sTabread_qBNCpf9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_sKhL8BeD, HV_BINOP_SUBTRACT, 0, m, &cBinop_sKhL8BeD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_AqGUiTsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2t6k5FLc, HV_BINOP_MAX, 0, m, &cBinop_2t6k5FLc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DUQ0zlGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AqGUiTsy, HV_BINOP_MULTIPLY, 0, m, &cBinop_AqGUiTsy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dDiM0QuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XfIdmImr_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_qBNCpf9u, 0, m, &sTabread_qBNCpf9u_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EbZTCnMf_sendMessage);
}

void Heavy_ChaffVerb::cSystem_cjGNZEmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sKhL8BeD, HV_BINOP_SUBTRACT, 1, m, &cBinop_sKhL8BeD_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LxbCx7gJ, 2, m, &cDelay_LxbCx7gJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jxF4dIUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cjGNZEmo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XfIdmImr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hEQwcLqc, 0, m, &cDelay_hEQwcLqc_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_LxbCx7gJ, 0, m, &cDelay_LxbCx7gJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5FOjbGz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_2t6k5FLc, HV_BINOP_MAX, 1, m, &cBinop_2t6k5FLc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2t6k5FLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dDiM0QuJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_dDiM0QuJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_EbZTCnMf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hEQwcLqc, 0, m, &cDelay_hEQwcLqc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6YGnhvH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hEQwcLqc, 2, m, &cDelay_hEQwcLqc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_sKhL8BeD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6YGnhvH2_sendMessage);
}

void Heavy_ChaffVerb::cCast_eJIAX18M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5enhUL8X, 0, m, &cVar_5enhUL8X_sendMessage);
  cMsg_2PPPyVsc_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_qB2wTfG7, 0, m, &cTabhead_qB2wTfG7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XigE9B95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Thxd8N4M_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Thxd8N4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_BvlAStti_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Db9oMUx0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Db9oMUx0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Tw4ombWu, 0, m, &cDelay_Tw4ombWu_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Db9oMUx0, 0, m, &cDelay_Db9oMUx0_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PMmodRQQ, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_Tw4ombWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Tw4ombWu, m);
  cMsg_d4scSQLp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_DtNsl6il_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ioC7krKp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_LGOOmd0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_97CzejBb_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_UsPKnZC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PNmiphkR_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Db9oMUx0, 2, m, &cDelay_Db9oMUx0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JeUfZKJ9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_97CzejBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_UsPKnZC4, 0, m, &hTable_UsPKnZC4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BvlAStti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_LGOOmd0w_sendMessage);
}

void Heavy_ChaffVerb::cMsg_d4scSQLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_UsPKnZC4, 0, m, &hTable_UsPKnZC4_sendMessage);
}

void Heavy_ChaffVerb::cCast_JeUfZKJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Db9oMUx0, 0, m, &cDelay_Db9oMUx0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PNmiphkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Tw4ombWu, 2, m, &cDelay_Tw4ombWu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ioC7krKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PMmodRQQ, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_rPaFgR69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GUv3N79p, HV_BINOP_SUBTRACT, 0, m, &cBinop_GUv3N79p_sendMessage);
}

void Heavy_ChaffVerb::cMsg_a9CbhJDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_TTybr8Wr_sendMessage);
}

void Heavy_ChaffVerb::cSystem_TTybr8Wr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_wmx4KygR_sendMessage);
}

void Heavy_ChaffVerb::cVar_p83Xy4uz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7rxVyv3g_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_EaC6kLKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EaC6kLKx, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bXeBs3gO, 0, m, &cDelay_bXeBs3gO_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Cga4SIPa, 0, m, &sTabread_Cga4SIPa_sendMessage);
}

void Heavy_ChaffVerb::cDelay_bXeBs3gO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bXeBs3gO, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Cga4SIPa, 0, m, &sTabread_Cga4SIPa_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bXeBs3gO, 0, m, &cDelay_bXeBs3gO_sendMessage);
}

void Heavy_ChaffVerb::sTabread_Cga4SIPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_hCgPSAie, HV_BINOP_SUBTRACT, 0, m, &cBinop_hCgPSAie_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_RsOD759Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I1nCJbys, HV_BINOP_MAX, 0, m, &cBinop_I1nCJbys_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wmx4KygR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RsOD759Y, HV_BINOP_MULTIPLY, 0, m, &cBinop_RsOD759Y_sendMessage);
}

void Heavy_ChaffVerb::cBinop_GUv3N79p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XwnpfvQK_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_Cga4SIPa, 0, m, &sTabread_Cga4SIPa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f5RunY46_sendMessage);
}

void Heavy_ChaffVerb::cSystem_r4Qc2K46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hCgPSAie, HV_BINOP_SUBTRACT, 1, m, &cBinop_hCgPSAie_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bXeBs3gO, 2, m, &cDelay_bXeBs3gO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7rxVyv3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_r4Qc2K46_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XwnpfvQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EaC6kLKx, 0, m, &cDelay_EaC6kLKx_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_bXeBs3gO, 0, m, &cDelay_bXeBs3gO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NikOfn9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_I1nCJbys, HV_BINOP_MAX, 1, m, &cBinop_I1nCJbys_sendMessage);
}

void Heavy_ChaffVerb::cBinop_I1nCJbys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GUv3N79p, HV_BINOP_SUBTRACT, 1, m, &cBinop_GUv3N79p_sendMessage);
}

void Heavy_ChaffVerb::cCast_f5RunY46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EaC6kLKx, 0, m, &cDelay_EaC6kLKx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Ue5CI3Lc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EaC6kLKx, 2, m, &cDelay_EaC6kLKx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hCgPSAie_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Ue5CI3Lc_sendMessage);
}

void Heavy_ChaffVerb::cCast_mUy3xSdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_p83Xy4uz, 0, m, &cVar_p83Xy4uz_sendMessage);
  cMsg_a9CbhJDY_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_rPaFgR69, 0, m, &cTabhead_rPaFgR69_sendMessage);
}

void Heavy_ChaffVerb::cMsg_znghL8xy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MRi48z2n_sendMessage);
}

void Heavy_ChaffVerb::cSystem_MRi48z2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9LQzEIhf_sendMessage);
}

void Heavy_ChaffVerb::cDelay_zQPtTaw6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zQPtTaw6, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_lGSDM78E, 0, m, &cDelay_lGSDM78E_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zQPtTaw6, 0, m, &cDelay_zQPtTaw6_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PoZ1RtTs, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_lGSDM78E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lGSDM78E, m);
  cMsg_if8CCAc3_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_zAaWqPbJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_UWdjgfn8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_99Set3gK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vNxch7Ca_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_LWU36yW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vkXqRwdU_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_zQPtTaw6, 2, m, &cDelay_zQPtTaw6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KMqDkACk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vNxch7Ca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_LWU36yW2, 0, m, &hTable_LWU36yW2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9LQzEIhf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_99Set3gK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_if8CCAc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_LWU36yW2, 0, m, &hTable_LWU36yW2_sendMessage);
}

void Heavy_ChaffVerb::cCast_KMqDkACk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zQPtTaw6, 0, m, &cDelay_zQPtTaw6_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vkXqRwdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_lGSDM78E, 2, m, &cDelay_lGSDM78E_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UWdjgfn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PoZ1RtTs, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_lwzJdzf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TbBC2Tfm, HV_BINOP_SUBTRACT, 0, m, &cBinop_TbBC2Tfm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_50VIQsh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KtSWASmJ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_KtSWASmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9HknvAaZ_sendMessage);
}

void Heavy_ChaffVerb::cVar_DyEUVPv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ea3v9yin_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_egrzvyJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_egrzvyJ8, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cgSrdfzh, 0, m, &cDelay_cgSrdfzh_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_SWzBDsf1, 0, m, &sTabread_SWzBDsf1_sendMessage);
}

void Heavy_ChaffVerb::cDelay_cgSrdfzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cgSrdfzh, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_SWzBDsf1, 0, m, &sTabread_SWzBDsf1_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cgSrdfzh, 0, m, &cDelay_cgSrdfzh_sendMessage);
}

void Heavy_ChaffVerb::sTabread_SWzBDsf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_YEoTTorX, HV_BINOP_SUBTRACT, 0, m, &cBinop_YEoTTorX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_2qj4e2hV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9UxEqea2, HV_BINOP_MAX, 0, m, &cBinop_9UxEqea2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9HknvAaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2qj4e2hV, HV_BINOP_MULTIPLY, 0, m, &cBinop_2qj4e2hV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TbBC2Tfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_71BiitOh_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_SWzBDsf1, 0, m, &sTabread_SWzBDsf1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w8LC64eF_sendMessage);
}

void Heavy_ChaffVerb::cSystem_yKeDZUqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YEoTTorX, HV_BINOP_SUBTRACT, 1, m, &cBinop_YEoTTorX_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cgSrdfzh, 2, m, &cDelay_cgSrdfzh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ea3v9yin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yKeDZUqU_sendMessage);
}

void Heavy_ChaffVerb::cMsg_71BiitOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_egrzvyJ8, 0, m, &cDelay_egrzvyJ8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_cgSrdfzh, 0, m, &cDelay_cgSrdfzh_sendMessage);
}

void Heavy_ChaffVerb::cMsg_H4Fik5x4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_9UxEqea2, HV_BINOP_MAX, 1, m, &cBinop_9UxEqea2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9UxEqea2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TbBC2Tfm, HV_BINOP_SUBTRACT, 1, m, &cBinop_TbBC2Tfm_sendMessage);
}

void Heavy_ChaffVerb::cCast_w8LC64eF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_egrzvyJ8, 0, m, &cDelay_egrzvyJ8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IEHtG3lO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_egrzvyJ8, 2, m, &cDelay_egrzvyJ8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YEoTTorX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_IEHtG3lO_sendMessage);
}

void Heavy_ChaffVerb::cCast_at2UT3XP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DyEUVPv5, 0, m, &cVar_DyEUVPv5_sendMessage);
  cMsg_50VIQsh8_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_lwzJdzf0, 0, m, &cTabhead_lwzJdzf0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZlL3pCLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wsc6x9MM_sendMessage);
}

void Heavy_ChaffVerb::cSystem_wsc6x9MM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_3jN862jj_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ffkdcGZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ffkdcGZA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_9vXcNQ0j, 0, m, &cDelay_9vXcNQ0j_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ffkdcGZA, 0, m, &cDelay_ffkdcGZA_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_65YL1yEJ, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_9vXcNQ0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9vXcNQ0j, m);
  cMsg_1M6iZNso_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_Ojldjkgl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_tD9vNmhC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_6v4mazhT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BcwYblLN_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_rdzKRYQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kMhBHJbM_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ffkdcGZA, 2, m, &cDelay_ffkdcGZA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mTiDQ9Zy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BcwYblLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_rdzKRYQ3, 0, m, &hTable_rdzKRYQ3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3jN862jj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_6v4mazhT_sendMessage);
}

void Heavy_ChaffVerb::cMsg_1M6iZNso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_rdzKRYQ3, 0, m, &hTable_rdzKRYQ3_sendMessage);
}

void Heavy_ChaffVerb::cCast_mTiDQ9Zy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ffkdcGZA, 0, m, &cDelay_ffkdcGZA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kMhBHJbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_9vXcNQ0j, 2, m, &cDelay_9vXcNQ0j_sendMessage);
}

void Heavy_ChaffVerb::cMsg_tD9vNmhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_65YL1yEJ, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_hLUIyRXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rGnLFc9h, HV_BINOP_SUBTRACT, 0, m, &cBinop_rGnLFc9h_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ytmbZKEA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_pBaXc0Rv_sendMessage);
}

void Heavy_ChaffVerb::cSystem_pBaXc0Rv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Bf8rbLL3_sendMessage);
}

void Heavy_ChaffVerb::cVar_OrJJ709E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HZIqoziN_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_St1YrJMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_St1YrJMw, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_b6Qs53Zo, 0, m, &cDelay_b6Qs53Zo_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_BMSIfyoq, 0, m, &sTabread_BMSIfyoq_sendMessage);
}

void Heavy_ChaffVerb::cDelay_b6Qs53Zo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_b6Qs53Zo, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_BMSIfyoq, 0, m, &sTabread_BMSIfyoq_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_b6Qs53Zo, 0, m, &cDelay_b6Qs53Zo_sendMessage);
}

void Heavy_ChaffVerb::sTabread_BMSIfyoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_kT2oVM6B, HV_BINOP_SUBTRACT, 0, m, &cBinop_kT2oVM6B_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_9nzKfAOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YWccN7wY, HV_BINOP_MAX, 0, m, &cBinop_YWccN7wY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Bf8rbLL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9nzKfAOn, HV_BINOP_MULTIPLY, 0, m, &cBinop_9nzKfAOn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rGnLFc9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lsM20LhX_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_BMSIfyoq, 0, m, &sTabread_BMSIfyoq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HWweDBnY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_kXBeNJaj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kT2oVM6B, HV_BINOP_SUBTRACT, 1, m, &cBinop_kT2oVM6B_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_b6Qs53Zo, 2, m, &cDelay_b6Qs53Zo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HZIqoziN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kXBeNJaj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_lsM20LhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_St1YrJMw, 0, m, &cDelay_St1YrJMw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_b6Qs53Zo, 0, m, &cDelay_b6Qs53Zo_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SGPKZk7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_YWccN7wY, HV_BINOP_MAX, 1, m, &cBinop_YWccN7wY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YWccN7wY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rGnLFc9h, HV_BINOP_SUBTRACT, 1, m, &cBinop_rGnLFc9h_sendMessage);
}

void Heavy_ChaffVerb::cCast_HWweDBnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_St1YrJMw, 0, m, &cDelay_St1YrJMw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hl412BBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_St1YrJMw, 2, m, &cDelay_St1YrJMw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kT2oVM6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_hl412BBl_sendMessage);
}

void Heavy_ChaffVerb::cCast_PTUFSLg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OrJJ709E, 0, m, &cVar_OrJJ709E_sendMessage);
  cMsg_ytmbZKEA_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_hLUIyRXl, 0, m, &cTabhead_hLUIyRXl_sendMessage);
}

void Heavy_ChaffVerb::cVar_McgfNoUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_37thxS8c, 0, m, &cVar_37thxS8c_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1t6nBS8s, 0, m, &cVar_1t6nBS8s_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9hjrcvcZ, 0, m, &cVar_9hjrcvcZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lmvXltf9, 0, m, &cVar_lmvXltf9_sendMessage);
}

void Heavy_ChaffVerb::cVar_W6DshnkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_JNu3GXiu_sendMessage);
}

void Heavy_ChaffVerb::cPack_juuoRfZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_IoQu5Bvj, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_1t6nBS8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HL13zx6T, HV_BINOP_MULTIPLY, 0, m, &cBinop_HL13zx6T_sendMessage);
}

void Heavy_ChaffVerb::cMsg_YiUKr1sQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9256Hmrq_sendMessage);
}

void Heavy_ChaffVerb::cSystem_9256Hmrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IQ3hro5l_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_HL13zx6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_gmBvFW3U_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Axux86y9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HL13zx6T, HV_BINOP_MULTIPLY, 1, m, &cBinop_HL13zx6T_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IQ3hro5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Axux86y9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gmBvFW3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_MjS6xFPF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MjS6xFPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_t4CsbJhk_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_OKf3bfwp, m);
}

void Heavy_ChaffVerb::cBinop_t4CsbJhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_gfTtfgFG, m);
}

void Heavy_ChaffVerb::cVar_9hjrcvcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IqItg1RO, HV_BINOP_MULTIPLY, 0, m, &cBinop_IqItg1RO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7Y9YPvHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Ul3WUYYM_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Ul3WUYYM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0uwaXlif_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_IqItg1RO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_YPKKqxDH_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eSUZ5hmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IqItg1RO, HV_BINOP_MULTIPLY, 1, m, &cBinop_IqItg1RO_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0uwaXlif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_eSUZ5hmB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YPKKqxDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LBF9KxnU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LBF9KxnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_VaTvxvmx_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_HRwvpPef, m);
}

void Heavy_ChaffVerb::cBinop_VaTvxvmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OIto0O7t, m);
}

void Heavy_ChaffVerb::cVar_lmvXltf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pwOsg8XW, HV_BINOP_MULTIPLY, 0, m, &cBinop_pwOsg8XW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VAiBqgci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RhHB1aeA_sendMessage);
}

void Heavy_ChaffVerb::cSystem_RhHB1aeA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4MzUMetc_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_pwOsg8XW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_CRuICYx9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_axOUjR0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pwOsg8XW, HV_BINOP_MULTIPLY, 1, m, &cBinop_pwOsg8XW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4MzUMetc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_axOUjR0o_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CRuICYx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_aRbdoElY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aRbdoElY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UqP158i1_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_vc5D4XNY, m);
}

void Heavy_ChaffVerb::cBinop_UqP158i1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_ddq82qvS, m);
}

void Heavy_ChaffVerb::cBinop_mHVtWhxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_swYOleg7, 0, m, &cPack_swYOleg7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CQ2i70mZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_McgfNoUb, 0, m, &cVar_McgfNoUb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_JNu3GXiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_juuoRfZc, 0, m, &cPack_juuoRfZc_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qFSyqBm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_05mt9mV8, 0, m, &cPack_05mt9mV8_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_turQTxhP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_8omP5RGF_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_8omP5RGF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zS3PNeXY_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_plgUpczG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_plgUpczG, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_plgUpczG, 0, m, &cDelay_plgUpczG_sendMessage);
  cSwitchcase_flQRvxuy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_zS3PNeXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8omP5RGF_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_plgUpczG, 0, m, &cDelay_plgUpczG_sendMessage);
  cSwitchcase_flQRvxuy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_eQCAi8h7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ij266CW3_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ij266CW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_yFKRsTvl_sendMessage);
}

void Heavy_ChaffVerb::cVar_ebIsJQMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CO3z9KXD, HV_BINOP_MULTIPLY, 0, m, &cBinop_CO3z9KXD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8omP5RGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_plgUpczG, 0, m, &cDelay_plgUpczG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5c8Bnot1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_plgUpczG, 2, m, &cDelay_plgUpczG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yFKRsTvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CO3z9KXD, HV_BINOP_MULTIPLY, 1, m, &cBinop_CO3z9KXD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CO3z9KXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_5c8Bnot1_sendMessage);
}

void Heavy_ChaffVerb::cVar_sUNZH49O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_FUItVXxU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_9RnwR4Vs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_lcbEHw2b_sendMessage);
}

void Heavy_ChaffVerb::cVar_MzH7lMij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_E2pSBl7m_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_f9JLNq7Y, 0, m, &cIf_f9JLNq7Y_sendMessage);
}

void Heavy_ChaffVerb::cUnop_tYH8rM5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zleVGB4M, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_zleVGB4M_sendMessage);
}

void Heavy_ChaffVerb::cUnop_0Zu3sZM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zleVGB4M, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_zleVGB4M_sendMessage);
}

void Heavy_ChaffVerb::cIf_f9JLNq7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_0Zu3sZM5_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_tYH8rM5h_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_E2pSBl7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f9JLNq7Y, 1, m, &cIf_f9JLNq7Y_sendMessage);
}

void Heavy_ChaffVerb::cMsg_r5qafdjl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bceuj3rT_sendMessage);
}

void Heavy_ChaffVerb::cSystem_bceuj3rT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_p1YnRRZw_sendMessage);
}

void Heavy_ChaffVerb::cDelay_oOYF9uoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oOYF9uoQ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QbLvp6u0, 0, m, &cDelay_QbLvp6u0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oOYF9uoQ, 0, m, &cDelay_oOYF9uoQ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_m0F9mjOq, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_QbLvp6u0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QbLvp6u0, m);
  cMsg_rJUnZxZ1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_ujqKaFGh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_le3leKpg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_0cs3btJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cqmTRvF2_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_YAQgNGE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dHNp6Wng_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_oOYF9uoQ, 2, m, &cDelay_oOYF9uoQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F0pWbbn1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_cqmTRvF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_YAQgNGE6, 0, m, &hTable_YAQgNGE6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_p1YnRRZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_0cs3btJ5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rJUnZxZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_YAQgNGE6, 0, m, &hTable_YAQgNGE6_sendMessage);
}

void Heavy_ChaffVerb::cCast_F0pWbbn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oOYF9uoQ, 0, m, &cDelay_oOYF9uoQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dHNp6Wng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_QbLvp6u0, 2, m, &cDelay_QbLvp6u0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_le3leKpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_m0F9mjOq, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_Z1pFxwMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OQ8mj4oW, HV_BINOP_SUBTRACT, 0, m, &cBinop_OQ8mj4oW_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PBKp3SIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_v1w4txAI_sendMessage);
}

void Heavy_ChaffVerb::cSystem_v1w4txAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_czngRaxr_sendMessage);
}

void Heavy_ChaffVerb::cVar_9l63ipka_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vyQEPXj4_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_NWU12N7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NWU12N7l, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2BW7oHOw, 0, m, &cDelay_2BW7oHOw_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_AO9Dt6Us, 0, m, &sTabread_AO9Dt6Us_sendMessage);
}

void Heavy_ChaffVerb::cDelay_2BW7oHOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2BW7oHOw, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_AO9Dt6Us, 0, m, &sTabread_AO9Dt6Us_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2BW7oHOw, 0, m, &cDelay_2BW7oHOw_sendMessage);
}

void Heavy_ChaffVerb::sTabread_AO9Dt6Us_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_8YPbw2c0, HV_BINOP_SUBTRACT, 0, m, &cBinop_8YPbw2c0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_rvOwYJK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dkFYJPQy, HV_BINOP_MAX, 0, m, &cBinop_dkFYJPQy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_czngRaxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rvOwYJK4, HV_BINOP_MULTIPLY, 0, m, &cBinop_rvOwYJK4_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OQ8mj4oW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_m6R3xXpG_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_AO9Dt6Us, 0, m, &sTabread_AO9Dt6Us_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_diCMINwF_sendMessage);
}

void Heavy_ChaffVerb::cSystem_UG3BLNco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8YPbw2c0, HV_BINOP_SUBTRACT, 1, m, &cBinop_8YPbw2c0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2BW7oHOw, 2, m, &cDelay_2BW7oHOw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vyQEPXj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UG3BLNco_sendMessage);
}

void Heavy_ChaffVerb::cMsg_m6R3xXpG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NWU12N7l, 0, m, &cDelay_NWU12N7l_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_2BW7oHOw, 0, m, &cDelay_2BW7oHOw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4HNTCpEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_dkFYJPQy, HV_BINOP_MAX, 1, m, &cBinop_dkFYJPQy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dkFYJPQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OQ8mj4oW, HV_BINOP_SUBTRACT, 1, m, &cBinop_OQ8mj4oW_sendMessage);
}

void Heavy_ChaffVerb::cCast_diCMINwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NWU12N7l, 0, m, &cDelay_NWU12N7l_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5pNXV8N5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NWU12N7l, 2, m, &cDelay_NWU12N7l_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8YPbw2c0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5pNXV8N5_sendMessage);
}

void Heavy_ChaffVerb::cCast_S1lV9Zpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9l63ipka, 0, m, &cVar_9l63ipka_sendMessage);
  cMsg_PBKp3SIF_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Z1pFxwMs, 0, m, &cTabhead_Z1pFxwMs_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_dKtSKX0E_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ItG7zIEt_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_ItG7zIEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_55W7DggL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_7IRwgm6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yqZWGToG, HV_BINOP_ADD, 0, m, &cBinop_yqZWGToG_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_8BAqJt3P_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1gUeSwtK_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_1gUeSwtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rEFjhTad_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_oyNvYQZF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sYIyHrMu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qwB3PUXu_sendMessage);
}

void Heavy_ChaffVerb::cVar_SLSaTluj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CoEZQiQL, 0, m, &cVar_CoEZQiQL_sendMessage);
}

void Heavy_ChaffVerb::cVar_CoEZQiQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ETtRdf4, HV_BINOP_ADD, 0, m, &cBinop_7ETtRdf4_sendMessage);
}

void Heavy_ChaffVerb::cVar_RLY1jNaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_621r2hdR, HV_BINOP_ADD, 0, m, &cBinop_621r2hdR_sendMessage);
}

void Heavy_ChaffVerb::cVar_aDYRWDMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_BTOddFVn_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_A6xMTjV8, 0, m, &cIf_A6xMTjV8_sendMessage);
}

void Heavy_ChaffVerb::cUnop_2UHXqDBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_621r2hdR, HV_BINOP_ADD, 1, m, &cBinop_621r2hdR_sendMessage);
}

void Heavy_ChaffVerb::cUnop_x2At1KcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_621r2hdR, HV_BINOP_ADD, 1, m, &cBinop_621r2hdR_sendMessage);
}

void Heavy_ChaffVerb::cIf_A6xMTjV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_x2At1KcC_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_2UHXqDBZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_BTOddFVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A6xMTjV8, 1, m, &cIf_A6xMTjV8_sendMessage);
}

void Heavy_ChaffVerb::cVar_j9VIuGnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rPjjoaRE_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_sWCuA4RG, 0, m, &cIf_sWCuA4RG_sendMessage);
}

void Heavy_ChaffVerb::cUnop_gbmsKtBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BIQRgPHS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_VenX1utd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BIQRgPHS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_sWCuA4RG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_VenX1utd_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_gbmsKtBK_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_rPjjoaRE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sWCuA4RG, 1, m, &cIf_sWCuA4RG_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_BIQRgPHS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_eDca5gLV, 0, m, &cSlice_eDca5gLV_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vpFP4fCE, 0, m, &cSlice_vpFP4fCE_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3Exyyi8d_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RIRl9yNl_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_eDca5gLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_fCj1R3v7, 0, m, &cVar_fCj1R3v7_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_fCj1R3v7, 0, m, &cVar_fCj1R3v7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_vpFP4fCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_xt2C0tHQ, HV_BINOP_NEQ, 1, m, &cBinop_xt2C0tHQ_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_fCj1R3v7, 1, m, &cVar_fCj1R3v7_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_xt2C0tHQ, HV_BINOP_NEQ, 1, m, &cBinop_xt2C0tHQ_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_fCj1R3v7, 1, m, &cVar_fCj1R3v7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_fCj1R3v7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Myc0yjJp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O0BZ53Gb_sendMessage);
}

void Heavy_ChaffVerb::cIf_vbU9AHRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MUvUI2Ye_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TPWR5CRw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_MUvUI2Ye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xt2C0tHQ, HV_BINOP_NEQ, 1, m, &cBinop_xt2C0tHQ_sendMessage);
}

void Heavy_ChaffVerb::cCast_TPWR5CRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fCj1R3v7, 0, m, &cVar_fCj1R3v7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xt2C0tHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vbU9AHRz, 1, m, &cIf_vbU9AHRz_sendMessage);
}

void Heavy_ChaffVerb::cCast_3Exyyi8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xt2C0tHQ, HV_BINOP_NEQ, 0, m, &cBinop_xt2C0tHQ_sendMessage);
}

void Heavy_ChaffVerb::cCast_RIRl9yNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vbU9AHRz, 0, m, &cIf_vbU9AHRz_sendMessage);
}

void Heavy_ChaffVerb::cIf_CVXZj6jJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_SLSaTluj, 0, m, &cVar_SLSaTluj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_Wt3lE4fI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_CVXZj6jJ, 0, m, &cIf_CVXZj6jJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_NhZ8Y9PY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_CVXZj6jJ, 0, m, &cIf_CVXZj6jJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_ARSQaKva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_CVXZj6jJ, 0, m, &cIf_CVXZj6jJ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_8Y3Co807_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_oyNvYQZF, 0, m, &cVar_oyNvYQZF_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_HuKX1YxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RLY1jNaJ, 0, m, &cVar_RLY1jNaJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xnICDC5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Wt3lE4fI, 1, m, &cIf_Wt3lE4fI_sendMessage);
}

void Heavy_ChaffVerb::cMsg_05OKFJ5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ARSQaKva, 1, m, &cIf_ARSQaKva_sendMessage);
}

void Heavy_ChaffVerb::cMsg_G9MGSe7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Wt3lE4fI, 1, m, &cIf_Wt3lE4fI_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_NhZ8Y9PY, 1, m, &cIf_NhZ8Y9PY_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ARSQaKva, 1, m, &cIf_ARSQaKva_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nZPOBpXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7IRwgm6b, 0, m, &cVar_7IRwgm6b_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nvcfzKBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_nZPOBpXP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rEFjhTad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_oyNvYQZF, 0, m, &cVar_oyNvYQZF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zleVGB4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_31ihSQ87, HV_BINOP_MULTIPLY, 0, m, &cBinop_31ihSQ87_sendMessage);
}

void Heavy_ChaffVerb::cBinop_lcbEHw2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zleVGB4M, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_zleVGB4M_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GWFr8rlL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_NhZ8Y9PY, 1, m, &cIf_NhZ8Y9PY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_621r2hdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BUSAoNYG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SKaFzKuv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_A5fFbub0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_10JBhDWc, 0, m, &cVar_10JBhDWc_sendMessage);
}

void Heavy_ChaffVerb::cCast_BUSAoNYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A5fFbub0, HV_BINOP_ADD, 1, m, &cBinop_A5fFbub0_sendMessage);
}

void Heavy_ChaffVerb::cCast_SKaFzKuv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SLSaTluj, 0, m, &cVar_SLSaTluj_sendMessage);
}

void Heavy_ChaffVerb::cCast_O0BZ53Gb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_j8he2tA3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_Myc0yjJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_G9MGSe7H_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_dTPgtWIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fbORZrjg, 0, m, &cVar_fbORZrjg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_31ihSQ87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NhZ8Y9PY, 0, m, &cIf_NhZ8Y9PY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hTl5rXRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ARSQaKva, 0, m, &cIf_ARSQaKva_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IR0AUejU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_E4VmHeA0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_hTl5rXRZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_FUItVXxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_9PUWI8CJ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9PUWI8CJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_IR0AUejU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9RnwR4Vs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sUNZH49O, 1, m, &cVar_sUNZH49O_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dNTv7MMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DcRW0h9x, 0, m, &cVar_DcRW0h9x_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UHMzXVdS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ebIsJQMj, 0, m, &cVar_ebIsJQMj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_55W7DggL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_SLSaTluj, 0, m, &cVar_SLSaTluj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yqZWGToG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_70xehuI3, HV_BINOP_MULTIPLY, 0, m, &cBinop_70xehuI3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_70xehuI3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8Y3Co807, 0, m, &cIf_8Y3Co807_sendMessage);
}

void Heavy_ChaffVerb::cBinop_B8buSh8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A5fFbub0, HV_BINOP_ADD, 0, m, &cBinop_A5fFbub0_sendMessage);
}

void Heavy_ChaffVerb::cCast_qwB3PUXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SLSaTluj, 0, m, &cVar_SLSaTluj_sendMessage);
}

void Heavy_ChaffVerb::cCast_sYIyHrMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B8buSh8n, HV_BINOP_ADD, 1, m, &cBinop_B8buSh8n_sendMessage);
}

void Heavy_ChaffVerb::cCast_gCds5fKn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CVXZj6jJ, 1, m, &cIf_CVXZj6jJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_3G7jQZh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_dKtSKX0E_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_rXUui6Oe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7IRwgm6b, 0, m, &cVar_7IRwgm6b_sendMessage);
}

void Heavy_ChaffVerb::cCast_CYFkNQu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_70xehuI3, HV_BINOP_MULTIPLY, 1, m, &cBinop_70xehuI3_sendMessage);
}

void Heavy_ChaffVerb::cCast_xMHIpEIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8BAqJt3P_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_MCyhmUA4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8Y3Co807, 1, m, &cIf_8Y3Co807_sendMessage);
}

void Heavy_ChaffVerb::cCast_HSR7tYnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7IRwgm6b, 0, m, &cVar_7IRwgm6b_sendMessage);
}

void Heavy_ChaffVerb::cCast_Bgddvaq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yqZWGToG, HV_BINOP_ADD, 1, m, &cBinop_yqZWGToG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_26BKYTzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B8buSh8n, HV_BINOP_ADD, 0, m, &cBinop_B8buSh8n_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7ETtRdf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_26BKYTzE, HV_BINOP_MULTIPLY, 0, m, &cBinop_26BKYTzE_sendMessage);
}

void Heavy_ChaffVerb::cCast_pLgUOjVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SLSaTluj, 0, m, &cVar_SLSaTluj_sendMessage);
}

void Heavy_ChaffVerb::cCast_Hyb5ao0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_26BKYTzE, HV_BINOP_MULTIPLY, 1, m, &cBinop_26BKYTzE_sendMessage);
}

void Heavy_ChaffVerb::cCast_cNsyaV7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SLSaTluj, 0, m, &cVar_SLSaTluj_sendMessage);
}

void Heavy_ChaffVerb::cCast_wqHgPcBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ETtRdf4, HV_BINOP_ADD, 1, m, &cBinop_7ETtRdf4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_THPmGcqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Myc0yjJp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O0BZ53Gb_sendMessage);
}

void Heavy_ChaffVerb::cReceive_8a2K9Vk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GbfVv4Yt_sendMessage(_c, 0, m);
  cMsg_Ki142gGi_sendMessage(_c, 0, m);
  cMsg_331nt2nF_sendMessage(_c, 0, m);
  cMsg_XigE9B95_sendMessage(_c, 0, m);
  cMsg_znghL8xy_sendMessage(_c, 0, m);
  cMsg_ZlL3pCLg_sendMessage(_c, 0, m);
  cMsg_6Hkq6sZ4_sendMessage(_c, 0, m);
  cMsg_WDN0LzUP_sendMessage(_c, 0, m);
  cMsg_O9B4Guaw_sendMessage(_c, 0, m);
  cMsg_Zwjnzep5_sendMessage(_c, 0, m);
  cMsg_DTAV57HN_sendMessage(_c, 0, m);
  cMsg_nShWxKUE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_37thxS8c, 0, m, &cVar_37thxS8c_sendMessage);
  cMsg_YiUKr1sQ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1t6nBS8s, 0, m, &cVar_1t6nBS8s_sendMessage);
  cMsg_7Y9YPvHi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_9hjrcvcZ, 0, m, &cVar_9hjrcvcZ_sendMessage);
  cMsg_VAiBqgci_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lmvXltf9, 0, m, &cVar_lmvXltf9_sendMessage);
  cMsg_lWVhP7oF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_HX8LSDUE, 0, m, &cVar_HX8LSDUE_sendMessage);
  cMsg_AP5Fzc8P_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DcRW0h9x, 0, m, &cVar_DcRW0h9x_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nRFUM0Fb, 0, m, &cVar_nRFUM0Fb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fbORZrjg, 0, m, &cVar_fbORZrjg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_doj7YWZj, 0, m, &cVar_doj7YWZj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IdToH0BY, 0, m, &cVar_IdToH0BY_sendMessage);
  cMsg_eQCAi8h7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ebIsJQMj, 0, m, &cVar_ebIsJQMj_sendMessage);
  cMsg_r5qafdjl_sendMessage(_c, 0, m);
  cSwitchcase_Ov4weLRk_onMessage(_c, NULL, 0, m, NULL);
  cMsg_55W7DggL_sendMessage(_c, 0, m);
  cMsg_THPmGcqh_sendMessage(_c, 0, m);
  cMsg_rEFjhTad_sendMessage(_c, 0, m);
  cSwitchcase_turQTxhP_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_fxoTl2YJ, 0, m, &cVar_fxoTl2YJ_sendMessage);
  cMsg_xBQCMwnL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_27i6FdhF, 0, m, &cVar_27i6FdhF_sendMessage);
  cMsg_vL3T3KKO_sendMessage(_c, 0, m);
  cMsg_lkd1eUjl_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_KImUKwxq, 0, m, &cVar_KImUKwxq_sendMessage);
  cMsg_IJgtsQPi_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_qUsWkknu, 0, m, &cTabhead_qUsWkknu_sendMessage);
  cMsg_pG1N2APW_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_h8z30s9A, 0, m, &cVar_h8z30s9A_sendMessage);
  cMsg_xFCf5AHG_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_LMSlRzgO, 0, m, &cTabhead_LMSlRzgO_sendMessage);
  cMsg_DJmFJZif_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_dFOcwt4j, 0, m, &cVar_dFOcwt4j_sendMessage);
  cMsg_ldE8n61I_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_jDcDPxe9, 0, m, &cTabhead_jDcDPxe9_sendMessage);
  cMsg_TvIcJxyF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_j7w3qwJV, 0, m, &cVar_j7w3qwJV_sendMessage);
  cMsg_GLCYTS09_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JNl44N1c, 0, m, &cTabhead_JNl44N1c_sendMessage);
  cMsg_LlGrDop6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3j1Hd02f, 0, m, &cVar_3j1Hd02f_sendMessage);
  cMsg_PLvwRt3y_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_geCnZB9N, 0, m, &cTabhead_geCnZB9N_sendMessage);
  cMsg_JuJFHtJ7_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Fg4KlTcY, 0, m, &cVar_Fg4KlTcY_sendMessage);
  cMsg_FhtSHxc4_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_XPD1MOMq, 0, m, &cTabhead_XPD1MOMq_sendMessage);
  cMsg_5FOjbGz6_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_5enhUL8X, 0, m, &cVar_5enhUL8X_sendMessage);
  cMsg_2PPPyVsc_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_qB2wTfG7, 0, m, &cTabhead_qB2wTfG7_sendMessage);
  cMsg_NikOfn9h_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_p83Xy4uz, 0, m, &cVar_p83Xy4uz_sendMessage);
  cMsg_a9CbhJDY_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_rPaFgR69, 0, m, &cTabhead_rPaFgR69_sendMessage);
  cMsg_H4Fik5x4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DyEUVPv5, 0, m, &cVar_DyEUVPv5_sendMessage);
  cMsg_50VIQsh8_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_lwzJdzf0, 0, m, &cTabhead_lwzJdzf0_sendMessage);
  cMsg_SGPKZk7a_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_OrJJ709E, 0, m, &cVar_OrJJ709E_sendMessage);
  cMsg_ytmbZKEA_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_hLUIyRXl, 0, m, &cTabhead_hLUIyRXl_sendMessage);
  cMsg_4HNTCpEx_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_9l63ipka, 0, m, &cVar_9l63ipka_sendMessage);
  cMsg_PBKp3SIF_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Z1pFxwMs, 0, m, &cTabhead_Z1pFxwMs_sendMessage);
}

void Heavy_ChaffVerb::cReceive_HTaslcGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_dNTv7MMJ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_buCVE288_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j9VIuGnh, 0, m, &cVar_j9VIuGnh_sendMessage);
}

void Heavy_ChaffVerb::cReceive_4nIwuM3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MzH7lMij, 0, m, &cVar_MzH7lMij_sendMessage);
}

void Heavy_ChaffVerb::cReceive_XmbBXM5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_31ihSQ87, HV_BINOP_MULTIPLY, 1, m, &cBinop_31ihSQ87_sendMessage);
}

void Heavy_ChaffVerb::cReceive_21FpADwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wqHgPcBs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cNsyaV7Z_sendMessage);
}

void Heavy_ChaffVerb::cReceive_OAUVfwv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hyb5ao0H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pLgUOjVx_sendMessage);
}

void Heavy_ChaffVerb::cReceive_xITV5XxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RLY1jNaJ, 0, m, &cVar_RLY1jNaJ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_U0anIvcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HuKX1YxG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aDYRWDMO, 0, m, &cVar_aDYRWDMO_sendMessage);
}

void Heavy_ChaffVerb::cReceive_LsT4IpXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_UHMzXVdS_sendMessage);
}

void Heavy_ChaffVerb::cReceive_SBXfJlGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bgddvaq4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HSR7tYnJ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_JLJ7jWWy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CYFkNQu8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rXUui6Oe_sendMessage);
}

void Heavy_ChaffVerb::cReceive_4VdAMdF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MCyhmUA4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xMHIpEIk_sendMessage);
}

void Heavy_ChaffVerb::cReceive_xaCYwnlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_l0EJd1L6, m);
}

void Heavy_ChaffVerb::cReceive_oyHj9GYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_oskGjInu, m);
}

void Heavy_ChaffVerb::cReceive_T04VZtaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nRFUM0Fb, 0, m, &cVar_nRFUM0Fb_sendMessage);
}

void Heavy_ChaffVerb::cReceive_4LoD4si4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_dTPgtWIO_sendMessage);
}

void Heavy_ChaffVerb::cReceive_Dj8R1kiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mi05ABuW, 0, m, &cVar_mi05ABuW_sendMessage);
}

void Heavy_ChaffVerb::cReceive_JC74RZnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_F0r5GMAQ, 0, m, &cVar_F0r5GMAQ_sendMessage);
}

void Heavy_ChaffVerb::cReceive_LGIAuMdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HX8LSDUE, 0, m, &cVar_HX8LSDUE_sendMessage);
}

void Heavy_ChaffVerb::cReceive_5pTHeLHg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_v49UQBa2, m);
}

void Heavy_ChaffVerb::cReceive_7D72dwu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_1tf0MkIY, m);
}

void Heavy_ChaffVerb::cReceive_G6acpR5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rvOwYJK4, HV_BINOP_MULTIPLY, 1, m, &cBinop_rvOwYJK4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S1lV9Zpk_sendMessage);
}

void Heavy_ChaffVerb::cReceive_HE5X18RS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gCds5fKn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3G7jQZh1_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_HI3mnHp0, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_tmHAd2VJ, VOf(Bf4));
    __hv_line_f(&sLine_Opn3dCSY, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_uUJZmkUt, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_3DxtU3SJ, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_Ju40mYCt, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_96BBl98G, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_wAUzuz1y, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_Gap3YKaQ, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_90GwjrS1, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_lpiJNm31, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_ZwcNDYLG, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_JH7sdhMR, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_VaSkBIkc, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_6D6eVyGA, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_r7MPYTzx, VIf(I0));
    __hv_varread_f(&sVarf_F1JJac0h, VOf(Bf2));
    __hv_rpole_f(&sRPole_xu7hceyA, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_Ta73M6F0, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_eLGq56RT, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_v49UQBa2, VOf(Bf1));
    __hv_tabread_f(&sTabread_AO9Dt6Us, VOf(Bf5));
    __hv_varread_f(&sVarf_1tf0MkIY, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_m0F9mjOq, VIf(Bf9));
    __hv_varread_f(&sVarf_oskGjInu, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_qD1sV7Me, VOf(Bf9));
    __hv_varread_f(&sVarf_EU9QAWh4, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_XNiR5GyA, VOf(Bf2));
    __hv_rpole_f(&sRPole_qcxPoxe9, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_IoQu5Bvj, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_cxHaKAdV, VOf(Bf2));
    __hv_tabread_f(&sTabread_iCsspYTK, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_PFwPTWKO, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_qBNCpf9u, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_Cga4SIPa, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_BMSIfyoq, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_SWzBDsf1, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_8lQcHMil, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_AjIvwtaR, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_hVWls8Ft, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_PMmodRQQ, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_PoZ1RtTs, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_65YL1yEJ, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_7vvJkzSJ, VOf(Bf9));
    __hv_varread_f(&sVarf_OKf3bfwp, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_gfTtfgFG, VOf(Bf3));
    __hv_rpole_f(&sRPole_EHtjvt45, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_PDOmzqdP, VOf(Bf3));
    __hv_varread_f(&sVarf_HRwvpPef, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_OIto0O7t, VOf(Bf12));
    __hv_rpole_f(&sRPole_yDGxBN4w, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_5Y0oTXRm, VOf(Bf12));
    __hv_varread_f(&sVarf_vc5D4XNY, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_ddq82qvS, VOf(Bf11));
    __hv_rpole_f(&sRPole_3pAafqwQ, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_4YgJJoul, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_fTGzFUHW, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_faKXG8tJ, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_EBcVXs82, VIf(Bf11));
    __hv_line_f(&sLine_20hnk4af, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_l0EJd1L6, VOf(Bf2));
    __hv_mul_f(VIf(I0), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf13), VIf(Bf2), VOf(Bf13));
    __hv_add_f(VIf(Bf13), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
